@@ -11,6 +11,7 @@
 #include <fcitx/instance.h>
 #include <fcitx-utils/misc.h>
 #include <fcitx-module/dbus/dbus_public.h>
+#include <fcitx-utils/log.h>
 #include <string>
 
 #define FCITX_INPUTMETHOD_DBUS_INTERFACE "org.fcitx.Fcitx5.uosai"
@@ -121,9 +122,11 @@ public:
         } else {
             FCITX_WARN() << "UosAi: Failed to write DBus address file for display " << display;
         }
+        FCITX_INFO() << "UosAi: UosAi input method initialization completed for display " << display;
     }
 
     ~UosAiInputMethod() override {
+        FCITX_INFO() << "UosAi: Destroying UosAi input method for display " << display_;
         if (!pathWrote_.empty()) {
             unlink(pathWrote_.data());
         }
@@ -177,7 +180,9 @@ public:
         created();
     }
 
-    ~Fcitx4InputContext() override { InputContext::destroy(); }
+    ~Fcitx4InputContext() override {
+        InputContext::destroy(); 
+    }
 
     const char *frontend() const override { return "fcitx4"; }
 
@@ -279,7 +284,8 @@ public:
             focusIn();
         }
 
-        return keyEvent(event) ? 1 : 0;
+        bool handled = keyEvent(event);
+        return handled ? 1 : 0;
     }
 
 private:
@@ -340,7 +346,7 @@ void UosAiInputMethod::commitText(const std::string &text) {
     if(ic && ic->hasFocus()) {
         ic->commitString(text);
     } else {
-        FCITX_ERROR() << "No focused input context or context lost focus";
+        FCITX_ERROR() << "UosAi: No focused input context or context lost focus";
     }
 }
 
@@ -350,7 +356,7 @@ void UosAiInputMethod::deleteChar()
     if (ic && ic->hasFocus()) {
         ic->deleteSurroundingText(-1, 1);
     } else {
-        FCITX_ERROR() << "No focused input context or context lost focus";
+        FCITX_ERROR() << "UosAi: No focused input context or context lost focus";
     }
 }
 
@@ -370,7 +376,7 @@ void UosAiInputMethod::setPreEditOn(bool isOn)
             ic->commitString(preedit);
         }
     } else {
-        FCITX_ERROR() << "No focused input context or context lost focus";
+        FCITX_ERROR() << "UosAi: No focused input context or context lost focus";
     }
 }
 
@@ -386,7 +392,7 @@ void UosAiInputMethod::commitToPreEdit(const std::string &text)
         inputPanel.setClientPreedit(Text(text));
         ic->updatePreedit();
     } else {
-        FCITX_ERROR() << "No focused input context or context lost focus";
+        FCITX_ERROR() << "UosAi: No focused input context or context lost focus";
     }
 }
 
@@ -415,6 +421,7 @@ UosAIFrontendModule::UosAIFrontendModule(Instance *instance)
               } catch (const std::exception &e) {
                   FCITX_ERROR() << "UosAi: Failed to create input method for display " << display << ": " << e.what();
               } catch (...) {
+                  FCITX_ERROR() << "UosAi: Failed to create input method for display " << display;
               }
               return false;
           },
@@ -471,6 +478,7 @@ UosAIFrontendModule::UosAIFrontendModule(Instance *instance)
             this->onFocusOut(focusOutEvent);
         });
 
+    FCITX_INFO() << "UosAi: UosAI frontend module initialization completed";
 }
 
 dbus::Bus *UosAIFrontendModule::bus() {
