@@ -16,10 +16,13 @@
 
 #include <QtDBus>
 #include <QCommandLineParser>
+#include <QLoggingCategory>
 
 DWIDGET_USE_NAMESPACE
 UOSAI_USE_NAMESPACE
 
+Q_DECLARE_LOGGING_CATEGORY(logMain)
+
 constexpr char APP_NAME_KEY[]   =   "uos-ai-assistant";
 
 static const QList<QCommandLineOption> options = {
@@ -37,12 +40,17 @@ static const QList<QCommandLineOption> options = {
     {
         {"w", "wordwizard"},
         "Display Scratch toolbar when hidden"
+    },
+    {
+        {"s", "screenshot"},
+        "Start screenshot for AI analysis"
     }
 };
 
 Application::Application(int &argc, char **argv)
     : DApplication(argc, argv)
 {
+    qCDebug(logMain) << "Initializing UOS AI Application";
     setApplicationName(APP_NAME_KEY);
     setObjectName(APP_NAME_KEY);
     setOrganizationName("deepin");
@@ -65,6 +73,7 @@ Application::Application(int &argc, char **argv)
     connect(ServerWrapper::instance(), &ServerWrapper::sigAppendPrompt, this, &Application::onAppendPrompt);
     connect(ServerWrapper::instance(), &ServerWrapper::sigAddKnowledgeBase, this, &Application::onAddKnowledgeBasefile);
     connect(ServerWrapper::instance(), &ServerWrapper::sigToTranslate, this, &Application::onTranslate);
+    connect(ServerWrapper::instance(), &ServerWrapper::sigToStartScreenshot, this, &Application::onStartScreenshot);
     connect(&LocalModelServer::getInstance(), &LocalModelServer::sigToLaunchMgmtNoShow, this, &Application::onLaunchMgmtNoShow);
 }
 
@@ -79,6 +88,7 @@ Application::~Application()
 
 void Application::initialization()
 {
+    qCDebug(logMain) << "Starting application initialization";
     ServerWrapper::instance()->initialization();
 
     setAttribute(Qt::AA_UseHighDpiPixmaps);
@@ -88,60 +98,108 @@ void Application::initialization()
 
 void Application::initShortcut()
 {
-    //v25 treeland环境下不注册快捷键
-    if (ESystemContext::isTreeland())
+    if (ESystemContext::isTreeland()) {
+        qCDebug(logMain) << "Skip shortcut registration in treeland environment";
         return;
+    }
 
-    QDBusInterface shortcutDbus("com.deepin.daemon.Keybinding", "/com/deepin/daemon/Keybinding", "com.deepin.daemon.Keybinding", QDBusConnection::sessionBus());
+    qCInfo(logMain) << "Initializing application shortcuts";
+    ShortcutManager& shortcutMgr = ShortcutManager::getInstance();
+    
+    if (!shortcutMgr.isValid()) {
+        qCWarning(logMain) << "ShortcutManager D-Bus interface is not valid";
+        return;
+    }
 
-    QString wordwizardShortcut = tr("UOS AI FollowAlong/Write");
+    // 使用枚举获取快捷键控制位
+    int isUpdate = DbWrapper::localDbWrapper().getUpdatePromptBits(UpdatePromptBitType::SHORTCUT_UPDATE);
 
-    QDBusMessage msg = shortcutDbus.call("SearchShortcuts", "UOS AI");
-    QString info = msg.arguments().at(0).toString();
-    QJsonDocument jsonDoc = QJsonDocument::fromJson(info.toUtf8());
-    QJsonArray jsonArray = jsonDoc.array();
+    QString wordwizardName = tr("UOS AI FollowAlong/Write");
 
-    for (const QJsonValue &value : jsonArray) {
-        QJsonObject jsonObj = value.toObject();
-        QString id = jsonObj.value("Id").toString();
-        QString accel = jsonObj.value("Accels").toArray().at(0).toString();
-        QString name = jsonObj.value("Name").toString();
-        QString exec = jsonObj.value("Exec").toString();
-        //UOS AI快捷键更换
-        if (id == "UOS AI") {
-#ifdef COMPILE_ON_V20
-            if (ESystemContext::isWayland())
-                continue;
-#endif
-            if (id == name && accel == "<Super>C")
-                shortcutDbus.call("ModifyCustomShortcut", id, name, exec, "<Super>A");
-        } else if (id == "UOS AI Talk") {
-            if (id == name && accel == "<Control><Super>C")
-                shortcutDbus.call("ModifyCustomShortcut", id, name, exec, "<Control><Super>A");
-        } else {
-            //划词写作快捷键中英文切换
-            if (id != wordwizardShortcut && id == name)
-                shortcutDbus.call("DeleteCustomShortcut", id);
+    // 查询现有快捷键
+    QList<ShortcutInfo> shortcuts = shortcutMgr.searchShortcuts("UOS AI");
+    
+    ShortcutInfo wordWizardShortcut;
+    ShortcutInfo uosAiShortcut;
+    ShortcutInfo uosAiTalkShortcut;
+
+    for (const ShortcutInfo &shortcut : shortcuts) {
+        if (shortcut.id == "UOS AI") {
+            uosAiShortcut = shortcut;
+        } else if (shortcut.id == "UOS AI Talk") {
+            uosAiTalkShortcut = shortcut;
+        } else if (shortcut.id.contains("/")) {
+            wordWizardShortcut = shortcut;
         }
     }
 
-    shortcutDbus.call("AddCustomShortcut", wordwizardShortcut, "/usr/bin/uos-ai-assistant --wordwizard", "<Super><Space>");
-    shortcutDbus.call("AddCustomShortcut", "UOS AI Talk", "/usr/bin/uos-ai-assistant --talk", "<Control><Super>A");
+    //首次更新至v2.8,替换快捷键
+    if (isUpdate == 0) {
+        if (!wordWizardShortcut.id.isEmpty() && wordWizardShortcut.id == wordWizardShortcut.name && wordWizardShortcut.accel == "<Super>space") {
+            qCInfo(logMain) << "Modifying Wordwizard shortcut from" << wordWizardShortcut.accel << "to <Super>R";
+            shortcutMgr.modifyCustomShortcut(wordWizardShortcut.id, wordWizardShortcut.name, wordWizardShortcut.exec, "<Super>R");
+        }
+
+        if (!uosAiTalkShortcut.id.isEmpty() && uosAiTalkShortcut.id == uosAiTalkShortcut.name) {
+            if (uosAiTalkShortcut.accel == "<Control><Super>C" || uosAiTalkShortcut.accel == "<Control><Super>A") {
+                qCInfo(logMain) << "Modifying UOS AI Talk shortcut from" << uosAiTalkShortcut.accel << "to <Control><Super>space";
+                shortcutMgr.modifyCustomShortcut(uosAiTalkShortcut.id, uosAiTalkShortcut.name, uosAiTalkShortcut.exec, "<Control><Super>space");
+            }
+        }
+
+        if (!uosAiShortcut.id.isEmpty() && uosAiShortcut.id == uosAiShortcut.name) {
+#ifdef COMPILE_ON_V20
+            if (!ESystemContext::isWayland()) {
+#endif
+                if (uosAiShortcut.accel == "<Super>C" || uosAiShortcut.accel == "<Super>A") {
+                    //延迟执行，等待随航快捷键修改完成
+                    QTimer::singleShot(0, this, [uosAiShortcut]{
+                        qCInfo(logMain) << "Modifying UOS AI shortcut from" << uosAiShortcut.accel << "to <Super>space";
+                        ShortcutManager::getInstance().modifyCustomShortcut(uosAiShortcut.id, uosAiShortcut.name, uosAiShortcut.exec, "<Super>space");
+                    });
+                }
+#ifdef COMPILE_ON_V20
+            }
+#endif
+        }
+    }
+
+    //随航快捷键跟随语言切换名称
+    if (!wordWizardShortcut.id.isEmpty() && wordWizardShortcut.id == wordWizardShortcut.name &&  wordWizardShortcut.id !=wordwizardName)
+        shortcutMgr.deleteCustomShortcut(wordWizardShortcut.id);
+
+    shortcutMgr.addCustomShortcut(wordwizardName, "/usr/bin/uos-ai-assistant --wordwizard", "<Super>R");
+    qCInfo(logMain) << "Add wordwizard shortcut <Super>R";
+    shortcutMgr.addCustomShortcut("UOS AI Talk", "/usr/bin/uos-ai-assistant --talk", "<Control><Super>space");
+    qCInfo(logMain) << "Add UOS AI Talk shortcut <Control><Super>space";
 #ifdef COMPILE_ON_V20
     if (ESystemContext::isWayland()) {
-        shortcutDbus.call("AddCustomShortcut", "UOS AI", "/usr/bin/uos-ai-assistant --chat", "<Super>C");
+        shortcutMgr.addCustomShortcut("UOS AI", "/usr/bin/uos-ai-assistant --chat", "<Super>C");
+        qCInfo(logMain) << "Add UOS AI shortcut <Super>C";
         return;
     }
 #endif
-    shortcutDbus.call("AddCustomShortcut", "UOS AI", "/usr/bin/uos-ai-assistant --chat", "<Super>A");
-
+    shortcutMgr.addCustomShortcut("UOS AI", "/usr/bin/uos-ai-assistant --chat", "<Super>space");
+    qCInfo(logMain) << "Add UOS AI shortcut <Super>space";
+    
+#ifdef COMPILE_ON_V25
+    // 添加截图快捷键 Ctrl+Alt+Q (目前仅在v25版本下)
+    shortcutMgr.addCustomShortcut("UOS AI Screenshot", "/usr/bin/uos-ai-assistant --screenshot", "<Control><Alt>Q");
+    qCInfo(logMain) << "Add UOS AI Screenshot shortcut <Control><Alt>Q";
+#endif
 }
 
 void Application::launchMgmtWindow(bool showAddllmPage, bool onlyUseAgreement, bool isFromAiQuick, const QString &locateTitle)
 {
-    if (!checkAgreement())
+    if (!checkAgreement()) {
+        qCWarning(logMain) << "User agreement not accepted, cannot launch management window";
         return;
+    }
 
+    qCInfo(logMain) << "Launching management window with parameters:"
+                   << "showAddllmPage:" << showAddllmPage
+                   << "onlyUseAgreement:" << onlyUseAgreement
+                   << "isFromAiQuick:" << isFromAiQuick;
     launchMgmtWindowNoShow();
     m_mgmtWindow->showEx(showAddllmPage, onlyUseAgreement, isFromAiQuick, locateTitle);
 }
@@ -149,11 +207,13 @@ void Application::launchMgmtWindow(bool showAddllmPage, bool onlyUseAgreement, b
 void Application::launchMgmtWindowNoShow()
 {
     if (!m_mgmtWindow) {
-        m_mgmtWindow = new MgmtWindow(m_chatWindow);
+        qCInfo(logMain) << "Creating new management window";
+        m_mgmtWindow = new MgmtWindow();
         connect(m_mgmtWindow, &MgmtWindow::sigGenPersonalFAQ, this, &Application::sigGenPersonalFAQ, Qt::UniqueConnection);
         connect(m_mgmtWindow, &MgmtWindow::sigSetRedPointVisible, m_chatWindow, &ChatWindow::onRedPointVisible);
         if (m_wordWizard) {
             bool isHidden = m_wordWizard->queryHiddenStatus();
+            qCInfo(logMain) << "wordWizard hiddenStatus" << isHidden;
             m_mgmtWindow->onWordWizardHiddenStatus(isHidden);
             connect(m_wordWizard, &WordWizard::signalHiddenwidget, m_mgmtWindow, &MgmtWindow::onWordWizardHiddenStatus, Qt::UniqueConnection);
             connect(m_wordWizard, &WordWizard::signalAddDisabledApp, m_mgmtWindow, &MgmtWindow::onAddDisabledApp, Qt::UniqueConnection);
@@ -165,12 +225,17 @@ void Application::launchMgmtWindowNoShow()
 
 void Application::launchChatWindow(int index)
 {
-    if (!checkAgreement())
+    if (!checkAgreement()) {
+        qCWarning(logMain) << "User agreement not accepted, cannot launch chat window";
         return;
+    }
 
+    qCInfo(logMain) << "Launching chat window with index:" << index;
     if (!m_chatWindow) {
-        if (!DeepSeekInfo::checkAndShow())
+        if (!DeepSeekInfo::checkAndShow()) {
+            qCWarning(logMain) << "checkAndShow block launching chat window";
             return;
+        }
         m_chatWindow = ESystemContext::createWebWindow<ChatWindow>();
         connect(this, &Application::sigGenPersonalFAQ, m_chatWindow, &ChatWindow::onGenPersonalFAQ, Qt::UniqueConnection);
         connect(m_chatWindow, &ChatWindow::sigToAddKnowledgeBase, this, [this](const QStringList &knowledgeBasefile){
@@ -183,6 +248,7 @@ void Application::launchChatWindow(int index)
     m_chatWindow->showWindow(static_cast<ChatIndex>(index));
 
     QTimer::singleShot(3000, this, [this](){
+        qCInfo(logMain) << "Delayed launching mgmt window.";
         launchMgmtWindowNoShow();
         if (!m_mgmtWindow->isVisible())
             m_mgmtWindow->checkUpdateStatus();
@@ -194,45 +260,57 @@ void Application::launchChatWindow(int index)
 
 void Application::launchAboutWindow()
 {
-    if (!m_chatWindow) return;
-
+    if (!m_chatWindow) {
+        qWarning(logMain) << "Cannot launch about window - chat window not available";
+        return;
+    }
+    qCDebug(logMain) << "Showing about window";
     m_chatWindow->showAboutWindow();
 }
 
 void Application::launchWordWizard()
 {
-    // 设置窗口存在时，置顶设置窗口，而不是打开写作助手，避免写作助手打开了被遮挡又关不掉
-    if (m_mgmtWindow && m_mgmtWindow->isVisible()) {
-        m_mgmtWindow->activateWindow();
+    if (!m_wordWizard) {
+        qCWarning(logMain) << "Cannot launch word wizard - word wizard not initialized";
         return;
     }
-
-    if (!m_wordWizard) return;
-
+    qCInfo(logMain) << "Launching word wizard via shortcut";
     m_wordWizard->onShortcutPressed();
 }
 
-void Application::launchAiQuickDialog(int type, QString query, QPoint pos)
+void Application::launchAiQuickDialog(int type, QString query, QPoint pos, bool isCustom)
 {
+    qCInfo(logMain) << "Launching AI quick dialog with type:" << type << "query size:" << query.size();
     AiQuickDialog *aiQuickDlg = new AiQuickDialog(m_wordWizard);
-    aiQuickDlg->setQuery(type, query, pos);
+    aiQuickDlg->setQuery(type, query, pos, isCustom);
+
+    connect(m_wordWizard, &WordWizard::sigToCloseAiQuick, aiQuickDlg, [ aiQuickDlg ] {
+        if (aiQuickDlg)
+            aiQuickDlg->close();
+    });
+
     aiQuickDlg->show();
 }
 
 void Application::launchAiWriterDialog()
 {
+    qCInfo(logMain) << "Launching AI writer dialog";
     AiWriterDialog::instance().show();
 }
 
 void Application::initWordWizard(WordWizard *wizard)
 {
+    qCDebug(logMain) << "Initializing word wizard";
     m_wordWizard = wizard;
-    if (m_wordWizard)
+    if (m_wordWizard) {
         connect(m_wordWizard, &WordWizard::sigToLaunchAiQuick, this, &Application::onLaunchAiQuick, Qt::UniqueConnection);
+        connect(m_wordWizard, &WordWizard::sigToLaunchMgmt, this, &Application::onLaunchMgmt, Qt::UniqueConnection);
+    }
 }
 
 int Application::handleExistingArgument(int argc, char *argv[])
 {
+    qCDebug(logMain) << "Handling existing arguments";
     QStringList arguments;
     for (int i = 0; i < argc; ++i) {
         arguments << argv[i];
@@ -243,11 +321,11 @@ int Application::handleExistingArgument(int argc, char *argv[])
     parser.parse(arguments);
 
     if (parser.isSet("chat")) {
-        qInfo() << "Detects that an application already exists and will notify it of its launch chat window for text";
+        qCInfo(logMain) << "Processing --chat argument";
         QDBusInterface notification(DBUS_SERVER, DBUS_SERVER_PATH, DBUS_SERVER_INTERFACE, QDBusConnection::sessionBus());
         QString error = notification.call(QDBus::Block, "launchChatPage", ChatIndex::Text).errorMessage();
         if (!error.isEmpty()) {
-            qCritical() << error;
+            qCCritical(logMain) << "Failed to launch chat page via D-Bus:" << error;
             return -1;
         }
     } else if (parser.isSet("talk")) {
@@ -265,6 +343,14 @@ int Application::handleExistingArgument(int argc, char *argv[])
             qCritical() << error;
             return -1;
         }
+    } else if (parser.isSet("screenshot")) {
+        QDBusInterface notification(DBUS_SERVER, DBUS_SERVER_PATH, DBUS_SERVER_INTERFACE, QDBusConnection::sessionBus());
+        qCInfo(logMain) << "launch chat window for screenshot";
+        QString error = notification.call(QDBus::Block, "startScreenshot").errorMessage();
+        if (!error.isEmpty()) {
+            qCritical() << error;
+            return -1;
+        }
     }
 
     return 0;
@@ -272,6 +358,7 @@ int Application::handleExistingArgument(int argc, char *argv[])
 
 bool Application::handleWordWizardArgument(int argc, char *argv[])
 {
+    qCDebug(logMain) << "Checking for word wizard argument";
     QStringList arguments;
     for (int i = 0; i < argc; ++i) {
         arguments << argv[i];
@@ -281,7 +368,9 @@ bool Application::handleWordWizardArgument(int argc, char *argv[])
     parser.addOptions(options);
     parser.parse(arguments);
 
-    return parser.isSet("wordwizard");
+    bool result = parser.isSet("wordwizard");
+    qCDebug(logMain) << "Word wizard argument present:" << result;
+    return result;
 }
 
 void Application::onLaunchMgmt(bool showAddllmPage, bool onlyUseAgreement, bool isFromAiQuick, const QString &locateTitle)
@@ -309,9 +398,9 @@ void Application::onLaunchWordWizard()
     launchWordWizard();
 }
 
-void Application::onLaunchAiQuick(int type, QString query, QPoint pos)
+void Application::onLaunchAiQuick(int type, QString query, QPoint pos, bool isCustom)
 {
-    launchAiQuickDialog(type, query, pos);
+    launchAiQuickDialog(type, query, pos, isCustom);
 }
 
 void Application::onLaunchAiWriter()
@@ -322,35 +411,44 @@ void Application::onLaunchAiWriter()
 void Application::onInputPrompt(const QString &question, const QMap<QString, QString> &params)
 {
     if (QThread::currentThread() != qApp->thread()) {
-        qWarning() << "called thread is not main thread. do not show WelcomeDialog.";
+        qCWarning(logMain) << "Input prompt called from non-main thread";
         return;
     }
 
     if (!WelcomeDialog::isAgreed()) {
+        qCInfo(logMain) << "Showing welcome dialog for input prompt";
         WelcomeDialog::instance(false)->exec();
         return;
     }
 
     // 避免：窗口模式下，连续点击划词icon使得主窗口隐藏
     if (m_chatWindow == nullptr || !m_chatWindow->isActiveWindow()) {
+        qCInfo(logMain) << "Launching chat window for input prompt";
         launchChatWindow(ChatIndex::Text);
         m_chatWindow->show();
     }
+    qCDebug(logMain) << "Processing input prompt size:" << question.size();
     m_chatWindow->overrideQuestion(question, params);
 }
 
 void Application::onAppendPrompt(const QString &question)
 {
     if (QThread::currentThread() != qApp->thread()) {
-        qWarning() << "called thread is not main thread. do not show WelcomeDialog.";
+        qCWarning(logMain) << "Append prompt called from non-main thread";
         return;
     }
 
     // 避免：窗口模式下，连续点击划词icon使得主窗口隐藏
     if (m_chatWindow == nullptr || !m_chatWindow->isActiveWindow()) {
+        qCInfo(logMain) << "Launching chat window for append prompt";
         launchChatWindow(ChatIndex::Text);
+        if (m_chatWindow == nullptr) {
+            qCWarning(logMain) << "Agreement is not accepted";
+            return;
+        }
         m_chatWindow->show();
     }
+    qCDebug(logMain) << "Appending prompt size:" << question.size();
     m_chatWindow->appendQuestion(question);
 }
 
@@ -370,53 +468,80 @@ bool Application::checkAgreement()
 
 void Application::handleArgumentsParser(const QStringList &arguments)
 {
+    qCDebug(logMain) << "Parsing command line arguments";
     QCommandLineParser parser;
     parser.addOptions(options);
     parser.parse(arguments);
 
     if (parser.isSet("functions")) {
+        qCInfo(logMain) << "Listing available functions";
         bool notYetQueried = true;
-        qInfo() << FunctionHandler::queryAppFunctions(notYetQueried);
+        qCInfo(logMain) << FunctionHandler::queryAppFunctions(notYetQueried);
     }
 
     if (parser.isSet("chat")) {
+        qCInfo(logMain) << "Launching chat window from command line";
         launchChatWindow(ChatIndex::Text);
     } else if (parser.isSet("talk")) {
+        qCInfo(logMain) << "Launching talk window from command line";
         launchChatWindow(ChatIndex::Talk);
+    } else if (parser.isSet("screenshot")) {
+        qCInfo(logMain) << "Starting screenshot from command line";
+        onStartScreenshot();
     }
 }
 
 void Application::onAddKnowledgeBasefile(const QStringList &knowledgeBasefile)
 {
     if (QThread::currentThread() != qApp->thread()) {
-        qWarning() << "called thread is not main thread. do not show WelcomeDialog.";
+        qCWarning(logMain) << "Add knowledge base called from non-main thread";
         return;
     }
 
     if (!WelcomeDialog::isAgreed()) {
+        qCInfo(logMain) << "Showing welcome dialog for knowledge base addition";
         WelcomeDialog::instance(false)->exec();
         return;
     }
 
-    if (m_chatWindow == nullptr || !m_chatWindow->isActiveWindow()) {
+    if (m_chatWindow == nullptr || !m_chatWindow->isVisible()) {
+        qCInfo(logMain) << "Launching chat window for knowledge base addition";
         launchChatWindow(ChatIndex::Text);
         m_chatWindow->show();
     }
+    qCInfo(logMain) << "Adding knowledge base files:" << knowledgeBasefile;
     m_chatWindow->addKnowledgeBase(knowledgeBasefile);
 }
 
 void Application::onTranslate()
 {
-    if (!checkAgreement())
-        return;
-
-    // 设置窗口存在时，置顶设置窗口，而不是打开写作助手，避免写作助手打开了被遮挡又关不掉
-    if (m_mgmtWindow && m_mgmtWindow->isVisible()) {
-        m_mgmtWindow->activateWindow();
+    if (!checkAgreement()) {
+        qCWarning(logMain) << "Cannot translate - user agreement not accepted";
         return;
     }
 
-    if (!m_wordWizard) return;
-
+    if (!m_wordWizard) {
+        qCWarning(logMain) << "Cannot translate - word wizard not initialized";
+        return;
+    }
+    qCInfo(logMain) << "Executing translation via shortcut";
     m_wordWizard->onShortcutTranslate();
 }
+
+void Application::onSignalShowMgmtWindowAfterChatInitFinished()
+{
+    ChatWindow::setNeedShowLLMConfigWindow(true);
+}
+
+void Application::onStartScreenshot()
+{
+    if (!m_chatWindow) {
+        qCWarning(logMain) << "Chat window is not excited";
+        return;
+    }
+    qCInfo(logMain) << "Executing screenshot via shortcut";
+    // 调用EAiExecutor的startScreenshot方法
+    if (m_chatWindow) {
+        m_chatWindow->startScreenshot();
+    }
+}
