@@ -5,6 +5,9 @@
 #include "dbwrapper.h"
 
 #include <QtDBus>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logDBus)
 
 AppDbusObject::AppDbusObject(const QString &appId)
     : QObject(nullptr)
@@ -28,6 +31,7 @@ void AppDbusObject::cancelRequestTask(const QString &id)
     if (!checkAgreement())
         return;
 
+    qCDebug(logDBus) << "Cancelling request task with id:" << id;
     m_chatSession->cancelRequestTask(id);
 }
 
@@ -36,6 +40,7 @@ void AppDbusObject::updateLLMAccount()
     if (!checkAgreement())
         return;
 
+    qCInfo(logDBus) << "Updating LLM account";
     m_chatSession->updateLLMAccount();
 }
 
@@ -44,20 +49,23 @@ void AppDbusObject::executionAborted()
     if (!checkAgreement())
         return;
 
+    qCWarning(logDBus) << "Execution aborted";
     emit m_chatSession->executionAborted();
 }
 
 QStringList AppDbusObject::requestChatText(const QString &llmId, const QString &conversation, qreal temperature, bool stream)
 {
     if (!checkAgreement())
-        return QStringList();;
+        return QStringList();
 
     uint pid = QDBusConnection::sessionBus().interface()->servicePid(message().service());
     if (m_chatSession->appId() != LLMUtils::queryAppId(pid)) {
-        qWarning() << LLMUtils::queryAppId(pid) << " no permission to access!";
+        qCWarning(logDBus) << "Access denied for appId:" << LLMUtils::queryAppId(pid);
         sendErrorReply(QDBusError::AccessDenied, "no permission to access!");
         return QStringList();
     }
+
+    qCDebug(logDBus) << "Requesting chat text with llmId:" << llmId << "temperature:" << temperature << "stream:" << stream;
     QVariantHash params = {
         {PREDICT_PARAM_STREAM, QVariant(stream)},
         {PREDICT_PARAM_TEMPERATURE, QVariant(temperature)},
@@ -65,6 +73,7 @@ QStringList AppDbusObject::requestChatText(const QString &llmId, const QString &
     };
     const QPair<AIServer::ErrorType, QStringList> &chatText = m_chatSession->requestChatText(llmId, conversation, params);
     if (chatText.first != AIServer::NoError) {
+        qCWarning(logDBus) << "Failed to request chat text:" << chatText.second.value(1);
         sendErrorReply(QDBusError::NoServer, chatText.second.value(1));
         return QStringList();
     }
@@ -77,6 +86,7 @@ bool AppDbusObject::setCurrentLLMAccountId(const QString &id)
     if (!checkAgreement())
         return false;
 
+    qCDebug(logDBus) << "Setting current LLM account ID:" << id;
     return m_chatSession->setCurrentLLMAccountId(id);
 }
 
@@ -85,7 +95,9 @@ QString AppDbusObject::currentLLMAccountId()
     if (!checkAgreement())
         return QString();
 
-    return m_chatSession->currentLLMAccountId();
+    QString id = m_chatSession->currentLLMAccountId();
+    qCDebug(logDBus) << "Current LLM account ID:" << id;
+    return id;
 }
 
 QString AppDbusObject::queryLLMAccountList()
@@ -100,6 +112,7 @@ QString AppDbusObject::queryLLMAccountList()
 
 void AppDbusObject::launchLLMUiPage(bool showAddllmPage)
 {
+    qCDebug(logDBus) << "Launching LLM UI page, showAddllmPage:" << showAddllmPage;
     emit launchUI(showAddllmPage);
 }
 
@@ -109,10 +122,11 @@ bool AppDbusObject::checkAgreement()
         return true;
 
     if (QThread::currentThread() != qApp->thread()) {
-        qWarning() << "this request is not in main thread. do not show WelcomeDialog.";
+        qCWarning(logDBus) << "Request not in main thread, cannot show WelcomeDialog";
         return false;
     }
 
+    qCDebug(logDBus) << "Showing WelcomeDialog";
     WelcomeDialog::instance(false)->exec();
     return WelcomeDialog::isAgreed();
 }
