@@ -1,6 +1,6 @@
 #include "audiodbusinterface.h"
 
-#include <QDebug>
+#include <QLoggingCategory>
 #ifdef COMPILE_ON_QT6
 #include <QAudioDevice>
 #include <QMediaDevices>
@@ -8,6 +8,8 @@
 #include <QAudioDeviceInfo>
 #endif
 
+Q_DECLARE_LOGGING_CATEGORY(logDBus)
+
 AudioDbusInterface::AudioDbusInterface(QObject *parent)
     : QObject(parent)
 {
@@ -35,43 +37,63 @@ AudioDbusInterface *AudioDbusInterface::instance()
 bool AudioDbusInterface::isDefaultInputDeviceValid()
 {
 #ifdef COMPILE_ON_QT6
-    //QT6用description判断音频设备
-    if (QMediaDevices::defaultAudioInput().description() != m_defaultSource->description())
+    //QT6用description判断音频设备,如果QMediaDevices的description()为"Echo-Cancel Source"，说明开启了噪音抑制模式，跳过音频设备判断
+    if (QMediaDevices::defaultAudioInput().description() != "Echo-Cancel Source" && QMediaDevices::defaultAudioInput().description() != m_defaultSource->description()) {
+        qCDebug(logDBus) << "Default input device mismatch";
         return false;
+    }
 #else
-    if (QAudioDeviceInfo::defaultInputDevice().deviceName() != m_defaultSource->name())
+    if (QAudioDeviceInfo::defaultInputDevice().deviceName() != m_defaultSource->name()) {
+        qCWarning(logDBus) << "Default input device mismatch";
         return false;
+    }
 #endif
 
     const AudioPort &activePort = m_defaultSource->activePort();
-    if (activePort.name.isEmpty())
+    if (activePort.name.isEmpty()) {
+        qCWarning(logDBus) << "Active port name is empty";
         return false;
+    }
 
-    if (!m_audioInter->IsPortEnabled(m_defaultSource->card(), activePort.name))
+    if (!m_audioInter->IsPortEnabled(m_defaultSource->card(), activePort.name)) {
+        qCWarning(logDBus) << "Port not enabled:" << activePort.name;
         return false;
+    }
 
-    return activePort.availability == 2 || activePort.availability == 0;
+    bool isValid = (activePort.availability == 2 || activePort.availability == 0);
+    qCInfo(logDBus) << "Input device validity:" << isValid;
+    return isValid;
 }
 
 bool AudioDbusInterface::isDefaultOutputDeviceValid()
 {
 #ifdef COMPILE_ON_QT6
     //QT6用description判断音频设备
-    if (QMediaDevices::defaultAudioOutput().description() != m_defaultSink->description())
+    if (QMediaDevices::defaultAudioOutput().description() != m_defaultSink->description()) {
+        qCDebug(logDBus) << "Default output device mismatch";
         return false;
+    }
 #else
-    if (QAudioDeviceInfo::defaultOutputDevice().deviceName() != m_defaultSink->name())
+    if (QAudioDeviceInfo::defaultOutputDevice().deviceName() != m_defaultSink->name()) {
+        qCWarning(logDBus) << "Default output device mismatch";
         return false;
+    }
 #endif
 
     const AudioPort &activePort = m_defaultSink->activePort();
-    if (activePort.name.isEmpty())
+    if (activePort.name.isEmpty()) {
+        qCWarning(logDBus) << "Active port name is empty";
         return false;
+    }
 
-    if (!m_audioInter->IsPortEnabled(m_defaultSink->card(), activePort.name))
+    if (!m_audioInter->IsPortEnabled(m_defaultSink->card(), activePort.name)) {
+        qCWarning(logDBus) << "Port not enabled:" << activePort.name;
         return false;
+    }
 
-    return activePort.availability == 2 || activePort.availability == 0;
+    bool isValid = (activePort.availability == 2 || activePort.availability == 0);
+    qCInfo(logDBus) << "Output device validity:" << isValid;
+    return isValid;
 }
 
 void AudioDbusInterface::setDefaultSource(const QDBusObjectPath &defaultSource)
@@ -83,6 +105,7 @@ void AudioDbusInterface::setDefaultSource(const QDBusObjectPath &defaultSource)
 #endif
     connect(m_defaultSource.data(), &Source::ActivePortChanged, this, &AudioDbusInterface::defaultInputChanged, Qt::QueuedConnection);
     QTimer::singleShot(5, this, SIGNAL(defaultInputChanged()));
+    qCDebug(logDBus) << "Default source changed:" << defaultSource.path();
 }
 
 void AudioDbusInterface::setDefaultSink(const QDBusObjectPath &defaultSink)
@@ -94,13 +117,15 @@ void AudioDbusInterface::setDefaultSink(const QDBusObjectPath &defaultSink)
 #endif
     connect(m_defaultSink.data(), &Sink::ActivePortChanged, this, &AudioDbusInterface::defaultOutputChanged, Qt::QueuedConnection);
     QTimer::singleShot(5, this, SIGNAL(defaultOutputChanged()));
+    qCDebug(logDBus) << "Default sink changed:" << defaultSink.path();
 }
 
 void AudioDbusInterface::onPortEnabledChanged(uint id, const QString &name, bool enable)
 {
+    qCDebug(logDBus) << "Port enabled changed - id:" << id << "name:" << name << "enable:" << enable;
     if (id == m_defaultSink->card() && m_defaultSink->activePort().name == name) {
         emit defaultOutputChanged();
-    } else  if (id == m_defaultSource->card() && m_defaultSource->activePort().name == name) {
+    } else if (id == m_defaultSource->card() && m_defaultSource->activePort().name == name) {
         emit defaultInputChanged();
     }
 }
