@@ -9,6 +9,9 @@
 #include <QDebug>
 #include <QtConcurrent>
 #include <QThreadPool>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logDBus)
 
 DBusInterface::DBusInterface(QObject *parent)
     : QObject(parent)
@@ -28,6 +31,7 @@ DBusInterface::~DBusInterface()
 
 void DBusInterface::onProcessTask(DBusInterface::TaskType type)
 {
+    qCDebug(logDBus) << "Processing task type:" << type;
     if (type == TASK_UPDATE_LLM_ACCOUNT) {
         updateLLMAccount();
     }
@@ -44,10 +48,13 @@ void DBusInterface::onRequestTaskFinished()
 
 void DBusInterface::updateLLMAccount()
 {
+    qCDebug(logDBus) << "Updating LLM accounts for all apps";
     for (auto iter = m_appDbusObjects.begin(); iter != m_appDbusObjects.end(); iter++) {
         QSharedPointer<AppDbusObject> appDbusObj = iter.value().object;
-        if (appDbusObj.isNull())
+        if (appDbusObj.isNull()) {
+            qCWarning(logDBus) << "Null app DBus object found for app:" << iter.key();
             continue;
+        }
 
         appDbusObj->updateLLMAccount();
     }
@@ -55,26 +62,31 @@ void DBusInterface::updateLLMAccount()
 
 void DBusInterface::asyncUpdateLLMAccount()
 {
+    qCDebug(logDBus) << "Scheduling async LLM account update";
     emit sigTask(TASK_UPDATE_LLM_ACCOUNT);
 }
 
 void DBusInterface::updateUserExpState(int state)
 {
+    qCDebug(logDBus) << "Updating user experience state:" << state;
     emit userExpStateChanged(state > 0);
 }
 
 void DBusInterface::updateVisibleState(bool visible)
 {
+    qCDebug(logDBus) << "Updating window visibility:" << visible;
     emit windowVisibleChanged(visible);
 }
 
 void DBusInterface::updateActiveState(bool active)
 {
+    qCDebug(logDBus) << "Updating window active state:" << active;
     emit windowActiveChanged(active);
 }
 
 void DBusInterface::addAppFunction(const QString &appId, const QJsonObject &funciton)
 {
+    qCDebug(logDBus) << "Adding function for app:" << appId;
     m_appFunctions[appId] << funciton;
 }
 
@@ -83,6 +95,7 @@ QJsonArray DBusInterface::appFunctions()
     const QString &appId = qApp->applicationName();
     const QJsonArray &functions = m_appFunctions.value(appId);
     m_appFunctions.remove(appId);
+    qCDebug(logDBus) << "Retrieved functions for app:" << appId << "count:" << functions.size();
     return functions;
 }
 
@@ -93,7 +106,9 @@ QString DBusInterface::version()
 
 bool DBusInterface::queryUserExpState()
 {
-    return DbWrapper::localDbWrapper().getUserExpState() > 0;
+    bool state = DbWrapper::localDbWrapper().getUserExpState() > 0;
+    qCDebug(logDBus) << "Querying user experience state:" << state;
+    return state;
 }
 
 QString DBusInterface::cachedFunctions()
@@ -101,38 +116,53 @@ QString DBusInterface::cachedFunctions()
     uint pid = QDBusConnection::sessionBus().interface()->servicePid(message().service());
     QString appId = LLMUtils::queryAppId(pid);
     const QJsonArray &functions = m_appFunctions.value(appId);
-    if (functions.isEmpty())
+    if (functions.isEmpty()) {
+        qCDebug(logDBus) << "No cached functions found for app:" << appId;
         return QString();
+    }
 
     QJsonObject rootObject;
     rootObject["functions"] = functions;
     QJsonDocument jsonDocument(rootObject);
     m_appFunctions.remove(appId);
+    qCDebug(logDBus) << "Retrieved cached functions for app:" << appId << "count:" << functions.size();
     return jsonDocument.toJson(QJsonDocument::Compact);
 }
 
 void DBusInterface::launchChatPage(int index)
 {
+    qCDebug(logDBus) << "Launching chat page with index:" << index;
     emit sigToLaunchChat(index);
 }
 
 void DBusInterface::launchWordWizard()
 {
+    qCDebug(logDBus) << "Launching word wizard";
     emit sigToLaunchWordWizard();
 }
 
 void DBusInterface::textTranslation()
 {
+    qCDebug(logDBus) << "Initiating text translation";
     emit sigToTranslate();
 }
 
+void DBusInterface::startScreenshot()
+{
+    qCDebug(logDBus) << "Initiating screenshot for AI analysis";
+    emit sigToStartScreenshot();
+}
+
 bool DBusInterface::isCopilotEnabled()
 {
-    return DbWrapper::localDbWrapper().getAICopilotIsOpen();
+    bool enabled = DbWrapper::localDbWrapper().getAICopilotIsOpen();
+    qCDebug(logDBus) << "Checking copilot status:" << enabled;
+    return enabled;
 }
 
 void DBusInterface::launchLLMUiPage(bool openAddAccountDialog)
 {
+    qCDebug(logDBus) << "Launching LLM UI page, openAddAccountDialog:" << openAddAccountDialog;
     emit sigToLaunchMgmt(openAddAccountDialog);
 }
 
@@ -144,15 +174,17 @@ QStringList DBusInterface::registerAppCmdPrompts(const QVariantMap &/*cmdPrompts
     uint pid = QDBusConnection::sessionBus().interface()->servicePid(message().service());
     const QString &appId = LLMUtils::queryAppId(pid);
 
-    if (appId.isEmpty())
+    if (appId.isEmpty()) {
+        qCWarning(logDBus) << "Empty appId received during registration";
         return QStringList();
+    }
 
     QDBusConnection connection = QDBusConnection::sessionBus();
     const QString &path = LLMUtils::adjustDbusPath(appId);
 
     if (m_appDbusObjects.contains(appId) && !m_appDbusObjects[appId].object.isNull()) {
         if (m_appDbusObjects[appId].cmdPrompts == cmdPrompts && connection.objectRegisteredAt(path)) {
-            qDebug() << path << " registered!";
+            qCDebug(logDBus) << "App already registered at path:" << path;
 
             QStringList reply;
             reply << path;
@@ -160,6 +192,7 @@ QStringList DBusInterface::registerAppCmdPrompts(const QVariantMap &/*cmdPrompts
             return reply;
         }
 
+        qCDebug(logDBus) << "Aborting existing execution for app:" << appId;
         m_appDbusObjects[appId].object->executionAborted();
     }
 
@@ -183,7 +216,9 @@ QStringList DBusInterface::registerAppCmdPrompts(const QVariantMap &/*cmdPrompts
     connection.unregisterObject(object.path);
     if (!connection.registerObject(object.path, object.object.data(), QDBusConnection::ExportScriptableSlots | QDBusConnection::ExportScriptableSignals)) {
         QDBusError error = connection.lastError();
-        qCritical() << "Failed to register DBus path: path, error = " << error.message();
+        qCCritical(logDBus) << "Failed to register DBus path:" << object.path << "error:" << error.message();
+    } else {
+        qCDebug(logDBus) << "Successfully registered DBus path:" << object.path;
     }
 
     DbWrapper::localDbWrapper().appendApp(object);
@@ -201,6 +236,7 @@ QString DBusInterface::registerApp()
 
 void DBusInterface::unregisterApp()
 {
+    qCDebug(logDBus) << "Unregistering app";
     unregisterAppCmdPrompts();
 }
 
@@ -214,4 +250,5 @@ void DBusInterface::unregisterAppCmdPrompts()
     connection.unregisterObject(path);
 
     m_appDbusObjects.remove(appId);
+    qCDebug(logDBus) << "Unregistered app:" << appId << "path:" << path;
 }
