@@ -94,6 +94,12 @@ public Q_SLOTS:
      */
     Q_SCRIPTABLE void textTranslation();
 
+    /**
+     * @brief ctrl + Alt + Q Start screenshot for AI analysis
+     * This function was added in v2.10
+     */
+    Q_SCRIPTABLE void startScreenshot();
+
     Q_SCRIPTABLE bool isCopilotEnabled();
 //to be removed in the future
 public Q_SLOTS:
@@ -144,6 +150,8 @@ signals:
 
     void sigToTranslate();
 
+    void sigToStartScreenshot();
+
 private slots:
     /**
      * @brief Execute the task received from the signal sigTask.
