@@ -1,21 +1,26 @@
 #include "dbusrequestbase.h"
-#include <QDebug>
+
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logDBus)
 
 DbusRequestBase::DbusRequestBase(const QString &service, const QString &path, const QString &interface, const QDBusConnection &connection, QObject *parent)
     : QDBusAbstractInterface(service, path, interface.toStdString().c_str(), connection, parent)
 {
     //关联后端dbus触发信号
     if (!QDBusConnection::sessionBus().connect(this->service(), this->path(), this->interface(), "", this, SLOT(slotDbusCall(QDBusMessage)))) {
-        qWarning() << "the connection was fail!" << "path: " << this->path() << "interface: " << this->interface();
-    };
+        qCWarning(logDBus) << "Failed to connect DBus signal - path:" << this->path() << "interface:" << this->interface();
+    }
+    
     //关联后端dbus触发信号
     if (!QDBusConnection::sessionBus().connect(this->service(), this->path(), "org.freedesktop.DBus.Properties", "", this, SLOT(slotDbusCall(QDBusMessage)))) {
-        qWarning() << "the connection was fail!" << "path: " << this->path() << "interface: " << this->interface();
-    };
+        qCWarning(logDBus) << "Failed to connect DBus Properties signal - path:" << this->path() << "interface:" << this->interface();
+    }
 }
 
 void DbusRequestBase::setCallbackFunc(CallbackFunc func)
 {
+    qCDebug(logDBus) << "Setting callback function";
     m_callbackFunc = func;
 }
 
@@ -27,6 +32,8 @@ void DbusRequestBase::setCallbackFunc(CallbackFunc func)
  */
 void DbusRequestBase::asyncCall(const QString &method, const QList<QVariant> &args)
 {
+    qCDebug(logDBus) << "Making async DBus call - method:" << method;
+    
     QDBusPendingCall async = QDBusAbstractInterface::asyncCall(method, args);
     CDBusPendingCallWatcher *watcher = new CDBusPendingCallWatcher(async, method, this);
     //将回调函数放进CallWatcher中，随CallWatcher调用结果返回
@@ -46,6 +53,7 @@ void DbusRequestBase::asyncCall(const QString &method,
                                 const QVariant &arg1, const QVariant &arg2, const QVariant &arg3, const QVariant &arg4,
                                 const QVariant &arg5, const QVariant &arg6, const QVariant &arg7, const QVariant &arg8)
 {
+    qCDebug(logDBus) << "Making async DBus call with multiple arguments - method:" << method;
     asyncCall(method, method, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8);
 }
 
@@ -59,6 +67,8 @@ void DbusRequestBase::asyncCall(const QString &method, const QString &callName,
                                 const QVariant &arg1, const QVariant &arg2, const QVariant &arg3, const QVariant &arg4,
                                 const QVariant &arg5, const QVariant &arg6, const QVariant &arg7, const QVariant &arg8)
 {
+    qCDebug(logDBus) << "Making async DBus call with named method - method:" << method << "callName:" << callName;
+    
     QList<QVariant> argList;
     int count = 0 + arg1.isValid() + arg2.isValid() + arg3.isValid() + arg4.isValid() +
                 arg5.isValid() + arg6.isValid() + arg7.isValid() + arg8.isValid();
