@@ -20,6 +20,8 @@
 #include <QTime>
 #include <QAnimationGroup>
 
+#include <mutex>
+
 DWIDGET_USE_NAMESPACE
 DGUI_USE_NAMESPACE
 DCORE_USE_NAMESPACE
@@ -52,6 +54,7 @@ enum ChatInitAsyncTask {
     ParserDocument = 1,
     OverrideQuestion,
     AddKnowledgeBase,
+    AddAskQuestion,
 };
 
 class ChatWindow : public DMainWindow
@@ -98,11 +101,25 @@ public:
 
     void overrideQuestion(const QString &question, const QMap<QString, QString> &ext);
     void appendQuestion(const QString &question);
+    void appendImage(const QString &imagePath);
+    void appendAskQuestion(int assistantType);
     void addKnowledgeBase(const QStringList &knowledgeBasefile);
 
     void setTitleBarMaskStatus(bool status);
+    void setTitleBarMaskBgColorAndShow(int r, int g, int b, int a);
 
-    void showWarningDialog(const QString assistantId, const QString conversationId, const QString msg, bool isDelete, bool isLlmDelete);
+    bool showWarningDialog(const QString assistantId, const QString conversationId, const QString msg, bool isDelete, bool isLlmDelete, bool isAllConvDelete);
+    bool showRmMcpServerDlg(const QString &name);
+    void showUpdateDialog(const QString &msg, const QString &appName);
+
+    void startScreenshot();
+
+    bool getThirdPartyMcpAgreement();
+    static void setNeedShowLLMConfigWindow(bool isNeedShowLLMConfigWindow);
+
+    void showKnowledgeBaseErrorDialog(int type, QString appName);
+
+    bool showLostFileWarningDlg(const QString lostFileList);
 protected:
     //rewrite mouseMoveEvent to block the mouse move event.
     void mouseMoveEvent(QMouseEvent *event) override;
@@ -124,6 +141,8 @@ private:
     void setW(int w);
     void setX(int x);
     void activeShowWindow();
+    QString getLatestUpdateLogVersion();
+    void checkForUpdateLogs();
 
 public Q_SLOTS:
     void onSystemThemeChanged();
@@ -153,6 +172,8 @@ private:
     static const int SidebarDefaultWidth = 400;
     static const int DefaultMargin = 10;  //10->0
     static const int AnimationTime = 300;
+    //是否在onChatInitFinished时打开设置窗口
+    static bool s_isNeedShowLLMConfigWindow;
 
     QRect m_displayRect;
     QRect m_geometry;
@@ -162,6 +183,7 @@ private:
     QAction *m_windowModeAction = nullptr;
     QAction *m_sidebarModeAction = nullptr;
     QAction *m_settingsAction = nullptr;
+    QAction *m_updateLogAction = nullptr;
 
     EChatButton *m_chatBtn = nullptr;
 
@@ -170,7 +192,7 @@ private:
 
     DisplayMode m_displayMode = SIDEBAR_MODE;
     bool m_isDigitalMode = false;
-    QSize m_windowSize = QSize(1010, 700); // 窗口模式下窗口尺寸
+    QSize m_windowSize = QSize(1010, 750); // 窗口模式下窗口尺寸
     // 1:silence, 2:listen, 3:think, 4:input, 5:network error, 6:input device error,
     // 7:stop recording, 8:account error, 9:recording error, 10:output device error
     int m_voiceConversationStatus = 0;
@@ -190,6 +212,10 @@ private:
     QList<AiTask> m_pendingTasks;
 
     EMaskWidget * m_mask;
+
+    mutable std::once_flag m_shortcutUpdateDialogOnceFlag;
+
+    bool m_needActiveWindow { true };
 };
 
 #endif // CHATWINDOW_H
