@@ -9,7 +9,6 @@
 #include "dconfigmanager.h"
 #include "util.h"
 #include "utils/apputils.h"
-
 #include "private/useragreementdialog.h"
 #include "private/modellistwidget.h"
 #include "private/operatinglinewidget.h"
@@ -23,16 +22,9 @@
 #include "private/getfreeaccountdialog.h"
 #include "private/wordwizardwidget.h"
 #include "private/aibarwidget.h"
+#include "private/mcpserverwidget.h"
 #include "private/privatemodellistwidget.h"
 
-#include <QVBoxLayout>
-#include <QHBoxLayout>
-#include <QScrollArea>
-#include <QScrollBar>
-#include <QStandardItemModel>
-#include <QApplication>
-#include <QTimer>
-
 #include <DWidgetUtil>
 #include <DLabel>
 #include <DBackgroundGroup>
@@ -40,9 +32,22 @@
 #include <DGuiApplicationHelper>
 #include <DTitlebar>
 #include <DDialog>
+#include <DFloatingMessage>
+
+#include <QVBoxLayout>
+#include <QHBoxLayout>
+#include <QScrollArea>
+#include <QScrollBar>
+#include <QStandardItemModel>
+#include <QApplication>
+#include <QTimer>
+#include <QLoggingCategory>
+#include <QGraphicsDropShadowEffect>
 
 using namespace uos_ai;
 
+Q_DECLARE_LOGGING_CATEGORY(logAIGUI)
+
 Q_DECLARE_METATYPE(QMargins)
 const QVariant VListViewItemMargin = QVariant::fromValue(QMargins(15, 0, 5, 0));
 
@@ -51,7 +56,7 @@ static constexpr char ShowInfo_Ok[] = ":/assets/images/ok_info.svg";
 MgmtWindow::MgmtWindow(DWidget *parent)
     : DMainWindow(parent)
 {
-    EWndManager()->registeWindow(this);
+//    EWndManager()->registeWindow(this);
 
     if (Util::checkLanguage()) {
         setFixedSize(800, 568);
@@ -60,10 +65,10 @@ MgmtWindow::MgmtWindow(DWidget *parent)
     }
     setWindowFlag(Qt::WindowMinMaxButtonsHint, false);              // 禁止窗口最大化和最小化按钮
     setWindowFlag(Qt::Dialog);                                       // 取消在底栏显示
-    setWindowModality(Qt::ApplicationModal);
+    setWindowModality(Qt::NonModal);
 
-    m_pAddDlg = new AddModelDialog(this);
-    m_pAddPrivateDlg = new AddPrivateModelDialog(this);
+    m_pAddDlg = new AddModelDialog();
+    m_pAddPrivateDlg = new AddPrivateModelDialog();
     m_pGetFreeAccountDialog = new GetFreeAccountDialog();
 
     initUI();
@@ -74,8 +79,15 @@ MgmtWindow::MgmtWindow(DWidget *parent)
 
 MgmtWindow::~MgmtWindow()
 {
-    if (m_pGetFreeAccountDialog)
+    if (m_pAddDlg) {
+        m_pAddDlg->deleteLater();
+    }
+    if (m_pAddPrivateDlg) {
+        m_pAddPrivateDlg->deleteLater();
+    }
+    if (m_pGetFreeAccountDialog) {
         m_pGetFreeAccountDialog->deleteLater();
+    }
 }
 
 void MgmtWindow::initUI()
@@ -127,6 +139,10 @@ void MgmtWindow::initUI()
 
     scrollLayout->addWidget(initModelConfigWidget(), 0, Qt::AlignCenter);
 
+#ifdef ENABLE_MCP
+    scrollLayout->addWidget(initMcpServerWidget(), 0, Qt::AlignCenter);
+#endif
+
     scrollLayout->addWidget(initWordWizardWidget(), 0, Qt::AlignLeft);
 
 #ifdef ENABLE_ASSISTANT
@@ -176,16 +192,8 @@ void MgmtWindow::initConnect()
         if (m_pLocalModelListWidget) m_pLocalModelListWidget->updateLocalModelList();
         this->activateWindow();
         this->show();
-        DFloatingMessage *message = new DFloatingMessage(DFloatingMessage::TransientType, this);
-        message->setMessage(tr("Successfully connected"));
-        message->setIcon(QIcon(ShowInfo_Ok));
 
-        QRect geometry(QPoint(0, 0), message->sizeHint());
-        geometry.moveCenter(rect().center());
-        geometry.moveBottom(rect().bottom() - 5);
-        message->setGeometry(geometry);
-
-        message->show();
+        showFloatingMessage(tr("Successfully connected"));
 
         if (m_isFromAiQuick) {
             EAiExec()->setUosAiLLMAccountId(m_pAddDlg->getModelData().id);
@@ -211,6 +219,7 @@ void MgmtWindow::initConnect()
             emit signalWordWizardStatusChanged(isShow);
         });
         connect(m_pWordWizardWidget, &WordWizardWidget::disabledAppsUpdateRequested, this, &MgmtWindow::signalDisabledAppsUpdated);
+        connect(m_pWordWizardWidget, &WordWizardWidget::skillAddedSuccessfully, this, &MgmtWindow::showFloatingMessage);
     }
 
     if (m_pAiBarWidget)
@@ -235,6 +244,7 @@ bool MgmtWindow::eventFilter(QObject *watched, QEvent *event)
 
 void MgmtWindow::closeEvent(QCloseEvent *event)
 {
+    qCDebug(logAIGUI) << "MgmtWindow closing";
     if (m_pModelListWidget)
         m_pModelListWidget->resetEditButton();
 
@@ -252,6 +262,7 @@ void MgmtWindow::closeEvent(QCloseEvent *event)
     emit signalCloseWindow();
 
     EmbeddingServer::getInstance().saveAllIndex();
+    qCInfo(logAIGUI) << "MgmtWindow closed, all indexes saved";
 
     DMainWindow::closeEvent(event);
 }
@@ -301,6 +312,7 @@ LocalModelListWidget *MgmtWindow::initLocalModelListWidget()
 
 void MgmtWindow::onAddModel()
 {
+    qCInfo(logAIGUI) << "Opening add model dialog";
     m_pAddDlg->resetDialog();
     m_pAddDlg->show();
     m_pAddDlg->adjustSize();
@@ -309,6 +321,7 @@ void MgmtWindow::onAddModel()
 
 void MgmtWindow::showAddPrivateModel()
 {
+    qCInfo(logAIGUI) << "Opening add private model dialog";
     m_pAddPrivateDlg->resetDialog();
     m_pAddPrivateDlg->show();
     m_pAddPrivateDlg->adjustSize();
@@ -317,23 +330,17 @@ void MgmtWindow::showAddPrivateModel()
 
 void MgmtWindow::onAddPrivateModel()
 {
+    qCInfo(logAIGUI) << "Adding new private model";
     m_pPrivateModelListWidget->onAppendModel(m_pAddPrivateDlg->getModelData());
 
     if (m_pLocalModelListWidget) m_pLocalModelListWidget->updateLocalModelList();
     this->activateWindow();
     this->show();
-    DFloatingMessage *message = new DFloatingMessage(DFloatingMessage::TransientType, this);
-    message->setMessage(tr("Successfully connected"));
-    message->setIcon(QIcon(ShowInfo_Ok));
 
-    QRect geometry(QPoint(0, 0), message->sizeHint());
-    geometry.moveCenter(rect().center());
-    geometry.moveBottom(rect().bottom() - 5);
-    message->setGeometry(geometry);
-
-    message->show();
+    showFloatingMessage(tr("Successfully connected"));
 
     if (m_isFromAiQuick) {
+        qCDebug(logAIGUI) << "Setting UOS AI LLM account ID from quick access";
         EAiExec()->setUosAiLLMAccountId(m_pAddDlg->getModelData().id);
     }
 }
@@ -360,7 +367,7 @@ DWidget *MgmtWindow::initAgreementWidget()
     oper->setEditText(tr("Read and agreed"));
 
     connect(oper, &OperatingLineWidget::signalNotDeleteButtonClicked, this, [this]() {
-        UserAgreementDialog dlg(this);
+        UserAgreementDialog dlg;
         dlg.exec();
     });
 
@@ -453,6 +460,18 @@ AiBarWidget *MgmtWindow::initAiBarWidget()
     return m_pAiBarWidget;
 }
 
+DWidget *MgmtWindow::initMcpServerWidget()
+{
+    m_pMcpServerWidget = new McpServerWidget(this);
+    m_pMcpServerWidget->setFixedWidth(560);
+    m_pMcpServerWidget->setProperty("title", m_pMcpServerWidget->getTitleName());
+    m_pMcpServerWidget->setProperty("level", 1);
+    titles.insert(m_pMcpServerWidget->getTitleName(), m_pMcpServerWidget);
+    widgetList.push_back(m_pMcpServerWidget);
+
+    return m_pMcpServerWidget;
+}
+
 DWidget *MgmtWindow::initModelConfigWidget()
 {
     DWidget *modelConfigWidget = new DWidget(this);
@@ -499,6 +518,8 @@ void MgmtWindow::showEx(bool showAddllmPage, bool onlyUseAgreement, bool isFromA
         m_pLocalModelListWidget->updateLocalModelList();
     if (m_pModelListWidget)
         m_pModelListWidget->checkActivityExists();
+    if (m_pMcpServerWidget)
+        m_pMcpServerWidget->updateStatus();
     if (m_pWordWizardWidget)
         m_pWordWizardWidget->updateHiddenStatus(m_bIsWordWizardHidden);
     if (m_pAiBarWidget)
@@ -511,6 +532,7 @@ void MgmtWindow::showEx(bool showAddllmPage, bool onlyUseAgreement, bool isFromA
     this->activateWindow();
     this->show();
     m_pNavigationWidget->onSelectGroup(locateTitle);
+    onNavigationSelected(locateTitle);
     if (showAddllmPage) {
         onAddModel();
     }
@@ -524,6 +546,7 @@ void MgmtWindow::checkUpdateStatus()
 
 void MgmtWindow::onShowGetFreeAccountDialog()
 {
+    qCDebug(logAIGUI) << "Showing get free account dialog";
     DDialog dlg(this);
     dlg.setIcon(QIcon(":/assets/images/warning.svg"));
 
@@ -532,6 +555,7 @@ void MgmtWindow::onShowGetFreeAccountDialog()
     QNetworkReply::NetworkError error = UosFreeAccounts::instance().getFreeAccount(ModelType::FREE_NORMAL, DeepSeek_Uos_Free, freeAccount, status);
 
     if (1 == status) {
+        qCWarning(logAIGUI) << "Free account activity has ended";
         dlg.setMessage(tr("The free account activity ends."));
         dlg.addButton(tr("Confirm", "button"), true, DDialog::ButtonNormal);
         dlg.exec();
@@ -539,6 +563,7 @@ void MgmtWindow::onShowGetFreeAccountDialog()
         return;
     }
     if (DDialog::Accepted == m_pGetFreeAccountDialog->exec()) {
+        qCInfo(logAIGUI) << "User accepted free account dialog";
         m_pGetFreeAccountDialog->onGetFreeAccount();
     }
 }
@@ -622,16 +647,22 @@ void MgmtWindow::onHiddenGetFreeAccountBtn()
 
 void MgmtWindow::onAddKnowledgeBase(const QStringList & filePath)
 {
-    if (filePath.isEmpty())
+    if (filePath.isEmpty()) {
+        qCWarning(logAIGUI) << "Attempted to add knowledge base with empty file path";
         return;
+    }
 
-    if (m_pKnowledgeBaseListWidget == nullptr)
+    if (m_pKnowledgeBaseListWidget == nullptr) {
+        qCWarning(logAIGUI) << "Knowledge base widget is null";
         return;
+    }
 
     if (m_pKnowledgeBaseListWidget->checkEmbeddingPluginsStatus()) {
+        qCInfo(logAIGUI) << "Adding knowledge base files:" << filePath;
         m_pKnowledgeBaseListWidget->addKnowledgeBaseFile(filePath);
     }
     else {
+        qCWarning(logAIGUI) << "Vectorization model plugin not installed";
         DDialog dialog("",tr("Adding to the knowledge base requires installing the vectorization model plugin. Please go to the app store to download and install."), this);
         dialog.setFixedWidth(380);
         dialog.setIcon(QIcon(":assets/images/warning.svg"));
@@ -643,6 +674,7 @@ void MgmtWindow::onAddKnowledgeBase(const QStringList & filePath)
         dialog.addButton(tr("Do not install", "button"), true, DDialog::ButtonNormal);
         dialog.addButton(tr("Install immediately", "button"), true, DDialog::ButtonRecommend);
         if (DDialog::Accepted == dialog.exec()) {
+            qCInfo(logAIGUI) << "User chose to install vectorization plugin";
             LocalModelServer::getInstance().openInstallWidgetOnTimer(PLUGINSNAME);
         }
     }
@@ -654,6 +686,7 @@ void MgmtWindow::onAddDisabledApp(const QString &appName)
         DisableAppWidget *disableWidget = m_pWordWizardWidget->getDisableAppWidget();
         if (disableWidget) {
             disableWidget->addApp(appName);
+            disableWidget->updateLayout();//减少多余渲染
         }
     }
 }
@@ -677,7 +710,30 @@ void MgmtWindow::loadDisabledApps()
             for (const QString &appName : disabledApps) {
                 disableWidget->addApp(appName);
             }
+            disableWidget->updateLayout();//减少多余渲染
             emit signalDisabledAppsUpdated(disabledApps);
         }
     }
 }
+
+void MgmtWindow::showFloatingMessage(const QString &message)
+{
+    DFloatingMessage *floatingMessage = new DFloatingMessage(DFloatingMessage::TransientType, this);
+    floatingMessage->setMessage(message);
+    floatingMessage->setIcon(QIcon(ShowInfo_Ok));
+    floatingMessage->setAttribute(Qt::WA_DeleteOnClose);
+
+    QGraphicsDropShadowEffect *shadowEffect = new QGraphicsDropShadowEffect(floatingMessage);
+    shadowEffect->setBlurRadius(30);
+    shadowEffect->setXOffset(2);
+    shadowEffect->setYOffset(2);
+    shadowEffect->setColor(QColor(0, 0, 0, int(255 * 0.2))); // (不透明度约20%)
+    floatingMessage->setGraphicsEffect(shadowEffect);
+
+    QRect geometry(QPoint(0, 0), floatingMessage->sizeHint());
+    geometry.moveCenter(rect().center());
+    geometry.moveBottom(rect().bottom() - 5);
+    floatingMessage->setGeometry(geometry);
+
+    floatingMessage->show();
+}
