@@ -17,6 +17,7 @@ class PrivateModelListWidget;
 class AddPrivateModelDialog;
 class AiBarWidget;
 class WordWizardWidget;
+class McpServerWidget;
 };
 
 class ModelListWidget;
@@ -49,6 +50,7 @@ public slots:
     void onHiddenGetFreeAccountBtn();
     void onAddKnowledgeBase(const QStringList & filePath);
     void onAddDisabledApp(const QString &appName);
+    void showFloatingMessage(const QString &message);
 
 private:
     void initUI();
@@ -64,6 +66,7 @@ private:
     KnowledgeBaseListWidget *initKnowledgeBaseWidget();
     uos_ai::WordWizardWidget *initWordWizardWidget();
     uos_ai::AiBarWidget *initAiBarWidget();
+    DWidget *initMcpServerWidget();
     DWidget *initModelConfigWidget();
 
 protected:
@@ -84,12 +87,13 @@ private:
     QWidget *m_pToastContent = nullptr;
     QScrollArea *m_pScrollArea = nullptr;
 
-    Navigation *m_pNavigationWidget = nullptr;
+    uos_ai::Navigation *m_pNavigationWidget = nullptr;
     ModelListWidget *m_pModelListWidget = nullptr;
     LocalModelListWidget *m_pLocalModelListWidget = nullptr;
     KnowledgeBaseListWidget *m_pKnowledgeBaseListWidget = nullptr;
     uos_ai::WordWizardWidget *m_pWordWizardWidget = nullptr;
     uos_ai::AiBarWidget *m_pAiBarWidget = nullptr;
+    uos_ai::McpServerWidget *m_pMcpServerWidget = nullptr;
     uos_ai::PrivateModelListWidget *m_pPrivateModelListWidget = nullptr;
 
 
