@@ -4,14 +4,8 @@
 #include "themedlable.h"
 #include "knowledgebaselistitem.h"
 #include "embeddingserver.h"
-
-#include <QVBoxLayout>
-#include <QHBoxLayout>
-#include <QStandardPaths>
-#include <QDBusInterface>
-#include <QDBusReply>
-#include <QDBusVariant>
-#include <QProcess>
+#include "localmodelserver.h"
+#include "knowledgebasemanager.h"
 
 #include <DLabel>
 #include <DFontSizeManager>
@@ -21,8 +15,19 @@
 #include <DArrowRectangle>
 #include <DFloatingWidget>
 
-static const qint64 KnowledgeBaseSize = 1024 * 1024 * 1024;
+#include <QVBoxLayout>
+#include <QHBoxLayout>
+#include <QStandardPaths>
+#include <QDBusInterface>
+#include <QDBusReply>
+#include <QDBusVariant>
+#include <QProcess>
+#include <QScreen>
+#include <QLoggingCategory>
 
+Q_DECLARE_LOGGING_CATEGORY(logAIGUI)
+
+static const qint64 KnowledgeBaseSize = 1024 * 1024 * 1024;
 
 KnowledgeBaseListWidget::KnowledgeBaseListWidget(DWidget *parent)
     : DWidget(parent)
@@ -41,20 +46,13 @@ KnowledgeBaseListWidget::KnowledgeBaseListWidget(DWidget *parent)
                       << "*.pdf";
     m_lastImportPath =  QStandardPaths::standardLocations(QStandardPaths::HomeLocation).first();
 
-    QStringList docFiles = EmbeddingServer::getInstance().getDocFiles();
-    setKnowledgeBaseList(docFiles);
-    foreach(const QString &file, docFiles) {
-        QFileInfo fileInfo(file);
-        QString name = fileInfo.fileName();
-        updateDocStatus(name, KnowledgeBaseProcessStatus::Succeed);
-    }
+    initKnowBaseList();
 }
 
 void KnowledgeBaseListWidget::initUI()
 {
     QVBoxLayout *layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
-    layout->setMargin(0);
     layout->setSpacing(10);
 
     m_pDeleteButton = new DCommandLinkButton(tr("Delete"), this);
@@ -64,14 +62,19 @@ void KnowledgeBaseListWidget::initUI()
     m_pAddButton = new DCommandLinkButton(tr("Add"), this);
     DFontSizeManager::instance()->bind(m_pAddButton, DFontSizeManager::T8, QFont::Normal);
 
+    m_pDeleteButton->setEnabled(false);
+    m_pDeleteButton->setToolTip(tr("Please install the embedding model plugins first"));
+    m_pAddButton->setEnabled(false);
+    m_pAddButton->setToolTip(tr("Please install the embedding model plugins first"));
+
     QHBoxLayout *topLayout = new QHBoxLayout;
     topLayout->setContentsMargins(0, 0, 0, 0);
-    topLayout->setMargin(0);
     topLayout->setSpacing(0);
 
-    ThemedLable *label = new ThemedLable(tr("Knowledge Base Management"));
-    label->setPaletteColor(QPalette::Text, DPalette::TextTitle);
-    DFontSizeManager::instance()->bind(label, DFontSizeManager::T5, QFont::Medium);
+    m_pWidgetLabel = new ThemedLable(tr("Knowledge Base Management"));
+    m_pWidgetLabel->setPaletteColor(QPalette::Text, DPalette::TextTitle);
+    DFontSizeManager::instance()->bind(m_pWidgetLabel, DFontSizeManager::T5, QFont::Bold);
+    m_pWidgetLabel->setElideMode(Qt::ElideRight);
 
 
     m_sizeLabel = new DLabel(this);
@@ -79,16 +82,14 @@ void KnowledgeBaseListWidget::initUI()
     DFontSizeManager::instance()->bind(m_sizeLabel, DFontSizeManager::T8, QFont::Medium);
     m_sizeLabel->setForegroundRole(DPalette::TextTips);
 
-    QString icon = QString(":/icons/deepin/builtin/%1/icons/tip.svg");
-    if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType)
-        icon = icon.arg("light");
-    else
-        icon = icon.arg("dark");
     m_tipIconLabel = new DLabel(this);
-    m_tipIconLabel->setPixmap(icon);
-    m_tipIconLabel->installEventFilter(this);
+    m_tipIconLabel->setPixmap(QIcon::fromTheme("uos-ai-assistant_tooltips").pixmap(16, 16));
+//    m_tipIconLabel->installEventFilter(this);
+    m_tipIconLabel->setToolTip("<p style=\'font-size: 12px\'>"+tr("This feature requires high hardware resources, and the reference benchmark configuration is: CPU Intel 11th generation i7 or above; "
+                                  "Memory of 16GB or more; Having a NVIDIA graphics card and a 10 series or higher is the best option. "
+                                  "If the configuration is too low, there may be issues such as lagging and inaccurate answers.") + "</p>");
 
-    topLayout->addWidget(label);
+    topLayout->addWidget(m_pWidgetLabel);
     topLayout->addSpacing(5);
     topLayout->addWidget(m_sizeLabel, 0, Qt::AlignCenter);
     topLayout->addSpacing(5);
@@ -114,12 +115,16 @@ void KnowledgeBaseListWidget::initConnect()
     connect(m_pDeleteButton, &DCommandLinkButton::clicked, this, &KnowledgeBaseListWidget::onEditButtonClicked);
     connect(m_pAddButton, &DCommandLinkButton::clicked, this, &KnowledgeBaseListWidget::onAddKnowledgeBase);
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &KnowledgeBaseListWidget::onThemeTypeChanged);
+    connect(&KnowledgeBaseManager::getInstance(), &KnowledgeBaseManager::filesProcessing, this, &KnowledgeBaseListWidget::onFilesProcessing);
     connect(&EmbeddingServer::getInstance(), &EmbeddingServer::addToServerStatusChanged, this, &KnowledgeBaseListWidget::onAddToServerStatusChanged);
     connect(&EmbeddingServer::getInstance(), &EmbeddingServer::indexDeleted, this, &KnowledgeBaseListWidget::onIndexDeleted);
+    connect(&LocalModelServer::getInstance(), &LocalModelServer::modelPluginsStatusChanged, this, &KnowledgeBaseListWidget::onEmbeddingPluginsStatusChanged);
+
 }
 
 void KnowledgeBaseListWidget::onThemeTypeChanged()
 {
+    qCDebug(logAIGUI) << "Theme type changed for KnowledgeBaseListWidget.";
     DPalette pl = m_pHasKnowledgeBaseWidget->palette();
     pl.setBrush(DPalette::Base, DGuiApplicationHelper::instance()->applicationPalette().color(DPalette::ItemBackground));
     m_pHasKnowledgeBaseWidget->setPalette(pl);
@@ -128,16 +133,12 @@ void KnowledgeBaseListWidget::onThemeTypeChanged()
     pl1.setBrush(DPalette::Base, DGuiApplicationHelper::instance()->applicationPalette().color(DPalette::ItemBackground));
     m_pNoKnowledgeBaseWidget->setPalette(pl1);
 
-    QString icon = QString(":/icons/deepin/builtin/%1/icons/tip.svg");
-    if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType)
-        icon = icon.arg("light");
-    else
-        icon = icon.arg("dark");
-    m_tipIconLabel->setPixmap(icon);
+    m_tipIconLabel->setPixmap(QIcon::fromTheme("uos-ai-assistant_tooltips").pixmap(16, 16));
 }
 
 void KnowledgeBaseListWidget::onEditButtonClicked()
 {
+    qCInfo(logAIGUI) << "Edit button clicked. EditMode:" << m_pDeleteButton->property("editMode").toBool();
     bool editMode = m_pDeleteButton->property("editMode").toBool();
     m_pDeleteButton->setProperty("editMode", !editMode);
     editMode = m_pDeleteButton->property("editMode").toBool();
@@ -179,7 +180,6 @@ DWidget *KnowledgeBaseListWidget::hasKnowledgeBaseWidget()
     DWidget *widget = new DWidget(this);
     auto layout = new QVBoxLayout(widget);
     layout->setContentsMargins(0, 0, 0, 0);
-    layout->setMargin(0);
 
     m_pHasKnowledgeBaseWidget = new DBackgroundGroup(layout, this);
     m_pHasKnowledgeBaseWidget->setContentsMargins(0, 0, 0, 0);
@@ -187,32 +187,99 @@ DWidget *KnowledgeBaseListWidget::hasKnowledgeBaseWidget()
     return m_pHasKnowledgeBaseWidget;
 }
 
-void KnowledgeBaseListWidget::setKnowledgeBaseList(QStringList &files)
-{
-    // 先将布局中的控件清空
-    QList<QWidget *> childWidgets = m_pHasKnowledgeBaseWidget->findChildren<QWidget *>();
-    for (QWidget *childWidget : childWidgets) {
-        childWidget->deleteLater();
-    }
-
-    for (auto file : files) {
-        onAppendKnowledgeBase(file);
-    }
-
-    adjustWidgetSize();
-}
-
 void KnowledgeBaseListWidget::removeKnowledgeBase(const QString &name)
 {
+    qCInfo(logAIGUI) << "Removing knowledge base. Name:" << name;
     KnowledgeBaseItem *item = m_pHasKnowledgeBaseWidget->findChild<KnowledgeBaseItem *>("KnowledgeBaseItem_" + name);
     if(!item)
         return;
 
-    if (item->status() == KnowledgeBaseProcessStatus::Succeed) {
-        QStringList fileList;
-        fileList << item->filePath();
-        EmbeddingServer::getInstance().deleteVectorIndex(fileList);
+    QStringList fileList;
+    fileList << item->filePath();
+
+    KnowledgeBaseManager::getInstance().removeFromKnowledgeBase(fileList);
+}
+
+bool KnowledgeBaseListWidget::onAppendKnowledgeBase(const QString &filePath, int status)
+{
+    QFileInfo fileInfo(filePath);
+    QString fileName = fileInfo.fileName();
+    KnowledgeBaseItem *item = m_pHasKnowledgeBaseWidget->findChild<KnowledgeBaseItem *>("KnowledgeBaseItem_" + fileName);
+    if (item) {
+        qCWarning(logAIGUI) << "File already exists in knowledge base. FileName:" << fileName;
+        DDialog dialog(tr("File already exist") ,
+                       tr("The %1 file already exists and cannot be added again. "
+                          "Please modify the file name or delete the existing file before adding it again").arg(fileName), this);
+        dialog.setFixedWidth(380);
+        dialog.setIcon(QIcon(":assets/images/warning.svg"));
+        dialog.addButton(QObject::tr("OK", "button"));
+        auto labelList = dialog.findChildren<QLabel *>();
+        for (auto messageLabel : labelList) {
+            if ("MessageLabel" == messageLabel->objectName()) {
+                messageLabel->setFixedWidth(dialog.width() - 20);
+            }
+        }
+        dialog.exec();
+        return false;
+    }
+
+    createKnowBaseItem(filePath, status);
+
+    return true;
+}
+
+void KnowledgeBaseListWidget::onAddKnowledgeBase()
+{
+    DFileDialog fileDlg(this);
+    fileDlg.setDirectory(m_lastImportPath);
+    QString selfilter = tr("All files") + (" (%1)");
+    selfilter = selfilter.arg(KnowledgeBaseManager::getInstance().supportedFormats().join(" "));
+    fileDlg.setViewMode(DFileDialog::Detail);
+    fileDlg.setFileMode(DFileDialog::ExistingFiles);
+    fileDlg.setNameFilter(selfilter);
+    fileDlg.selectNameFilter(selfilter);
+    fileDlg.setObjectName("fileDialogAdd");
+    if (DFileDialog::Accepted == fileDlg.exec()) {
+        m_lastImportPath = fileDlg.directory().path();
+        addKnowledgeBaseFile(fileDlg.selectedFiles());
+    }
+}
+
+void KnowledgeBaseListWidget::addKnowledgeBaseFile(const QStringList &fileList)
+{
+    auto result = KnowledgeBaseManager::getInstance().addExistingFiles(fileList);
+
+    if (result.result == KnowledgeBaseManager::AddResult::Success)
+        refreshKnowBaseList();
+}
+
+void KnowledgeBaseListWidget::onAddToServerStatusChanged(const QStringList &files, int status)
+{
+    qCDebug(logAIGUI) << "AddToServerStatusChanged. Files:" << files << ", Status:" << status;
+    if (files.isEmpty()) {
+        // getDoc()新接口statusChanged信号不带参数，直接刷新列表
+        refreshKnowBaseList();
     } else {
+        // 兼容旧接口
+        refreshKnowBaseListOld(files, status);
+    }
+
+//    if (status == 1) {
+//        TODO 信号弃用，后续清理
+//        emit sigGenPersonalFAQ();
+//    }
+}
+
+void KnowledgeBaseListWidget::onIndexDeleted(const QStringList &files)
+{
+    qCInfo(logAIGUI) << "Index deleted. Files:" << files;
+    foreach(QString file, files) {
+        QFileInfo fileInfo(file);
+        KnowledgeBaseItem *item = m_pHasKnowledgeBaseWidget->findChild<KnowledgeBaseItem *>("KnowledgeBaseItem_" + fileInfo.fileName());
+        if (!item)
+            continue;
+
+        updateFileSize(-item->fileSize());
         m_pHasKnowledgeBaseWidget->layout()->removeWidget(item);
         item->setParent(nullptr);
         delete item;
@@ -221,13 +288,56 @@ void KnowledgeBaseListWidget::removeKnowledgeBase(const QString &name)
     }
 }
 
-void KnowledgeBaseListWidget::onAppendKnowledgeBase(const QString &filePath)
+void KnowledgeBaseListWidget::onFilesProcessing(const QStringList &files)
+{
+    for (const QString &file : files)
+        onAppendKnowledgeBase(file, KnowledgeBaseProcessStatus::Processing);
+}
+
+void KnowledgeBaseListWidget::onEmbeddingPluginsStatusChanged(bool isExist)
+{
+    qCDebug(logAIGUI) << "Embedding plugins status changed. Exist:" << isExist;
+    if (!isExist) {
+        resetEditButton();
+        m_pDeleteButton->setEnabled(false);
+        m_pDeleteButton->setToolTip(tr("Please install the embedding model plugins first"));
+        m_pAddButton->setEnabled(false);
+        m_pAddButton->setToolTip(tr("Please install the embedding model plugins first"));
+    }
+    else {
+        m_pDeleteButton->setEnabled(true);
+        m_pDeleteButton->setToolTip("");
+        m_pAddButton->setEnabled(true);
+        m_pAddButton->setToolTip("");
+    }
+}
+
+void KnowledgeBaseListWidget::onRefresh()
+{
+    refreshKnowBaseList();
+}
+
+void KnowledgeBaseListWidget::adjustWidgetSize()
+{
+    if (m_pHasKnowledgeBaseWidget->layout()->count() <= 0) {
+        m_pNoKnowledgeBaseWidget->show();
+        m_pHasKnowledgeBaseWidget->hide();
+        m_pDeleteButton->hide();
+        m_pDeleteButton->setProperty("editMode", false);
+        if (checkEmbeddingPluginsStatus())
+            m_pAddButton->setEnabled(true);
+    } else {
+        m_pNoKnowledgeBaseWidget->hide();
+        m_pHasKnowledgeBaseWidget->show();
+        m_pDeleteButton->show();
+    }
+    adjustSize();
+}
+
+void KnowledgeBaseListWidget::createKnowBaseItem(const QString &filePath, int status)
 {
     QFileInfo fileInfo(filePath);
     QString fileName = fileInfo.fileName();
-    KnowledgeBaseItem *item = m_pHasKnowledgeBaseWidget->findChild<KnowledgeBaseItem *>("KnowledgeBaseItem_" + fileName);
-    if (item) return;
-
     QFile file(filePath);
     qint64 bytes = 0;
     if (file.exists()) {
@@ -235,9 +345,25 @@ void KnowledgeBaseListWidget::onAppendKnowledgeBase(const QString &filePath)
         bytes = fileInfo.size();
     }
 
-    KnowledgeBaseItem *newItem = new KnowledgeBaseItem(fileName, filePath, this);
-    newItem->setStatus(KnowledgeBaseProcessStatus::Processing);
+    KnowledgeBaseProcessStatus knowStatus = KnowledgeBaseProcessStatus::Processing;
+    switch (status) {
+    case 0:
+        knowStatus = KnowledgeBaseProcessStatus::Processing;
+        break;
+    case -1:  // 兼容getDocFiles V1.0接口
+    case 1:
+        knowStatus = KnowledgeBaseProcessStatus::Succeed;
+        break;
+    case 2:
+        knowStatus = KnowledgeBaseProcessStatus::FileError;
+        break;
+    case 3:
+        knowStatus = KnowledgeBaseProcessStatus::ProcessingError;
+        break;
+    }
 
+    KnowledgeBaseItem *newItem = new KnowledgeBaseItem(fileName, filePath, this);
+    newItem->setStatus(knowStatus);
     newItem->setFileSize(bytes);
     updateFileSize(bytes);
 
@@ -248,100 +374,63 @@ void KnowledgeBaseListWidget::onAppendKnowledgeBase(const QString &filePath)
     m_pDeleteButton->setText(tr("Delete"));
 }
 
-bool KnowledgeBaseListWidget::onAppendKnowledgeBase(const QStringList &filePathList)
+void KnowledgeBaseListWidget::initKnowBaseList()
 {
-    bool ret = true;
-    bool isFileAlreadyExist = false;
-    QString fileName = "";
-    for (QString filePath : filePathList) {
-        QFileInfo fileInfo(filePath);
-        fileName = fileInfo.fileName();
-        KnowledgeBaseItem *item = m_pHasKnowledgeBaseWidget->findChild<KnowledgeBaseItem *>("KnowledgeBaseItem_" + fileName);
-        if (item) {
-            isFileAlreadyExist = true;
+    // 先将布局中的控件清空
+    QList<QWidget *> childWidgets = m_pHasKnowledgeBaseWidget->findChildren<QWidget *>();
+    for (QWidget *childWidget : childWidgets) {
+        childWidget->deleteLater();
+    }
+
+    QVector<QPair<int, QString>> files = KnowledgeBaseManager::getInstance().getKnowledgeBaseFiles();
+    for (auto file : files) {
+        createKnowBaseItem(file.second, file.first);
+    }
+}
+
+void KnowledgeBaseListWidget::refreshKnowBaseList()
+{
+    qCDebug(logAIGUI) << "Refreshing knowledge base list.";
+    QVector<QPair<int, QString>> files = KnowledgeBaseManager::getInstance().getKnowledgeBaseFiles();
+
+    for (auto file : files) {
+        QString filePath = file.second;
+        int status = file.first;
+
+        KnowledgeBaseProcessStatus knowStatus = KnowledgeBaseProcessStatus::Processing;
+        switch (status) {
+        case 0:
+            knowStatus = KnowledgeBaseProcessStatus::Processing;
+            break;
+        case -1: // 兼容V1.0
+        case 1:
+            knowStatus = KnowledgeBaseProcessStatus::Succeed;
+            break;
+        case 2:
+            knowStatus = KnowledgeBaseProcessStatus::FileError;
+            break;
+        case 3:
+            knowStatus = KnowledgeBaseProcessStatus::ProcessingError;
             break;
         }
-    }
 
-    if (isFileAlreadyExist) {
-        // 已存在同名文件
-        DDialog dialog(tr("File already exist") ,
-                       tr("The %1 file already exists and cannot be added again. "
-                          "Please modify the file name or delete the existing file before adding it again").arg(fileName));
-        dialog.setIcon(QIcon(":assets/images/warning.svg"));
-        dialog.addButton(QObject::tr("OK", "button"));
-        dialog.exec();
-        ret = false;
-    } else {
-        for (QString filePath : filePathList) {
-            onAppendKnowledgeBase(filePath);
-        }
-    }
-
-    return ret;
-}
-void KnowledgeBaseListWidget::onAddKnowledgeBase()
-{
-    DFileDialog fileDlg(this);
-    fileDlg.setDirectory(m_lastImportPath);
-    QString selfilter = tr("All files") + (" (%1)");
-    selfilter = selfilter.arg(m_supportedSuffix.join(" "));
-    fileDlg.setViewMode(DFileDialog::Detail);
-    fileDlg.setFileMode(DFileDialog::ExistingFiles);
-    fileDlg.setOption(DFileDialog::HideNameFilterDetails);
-    fileDlg.setNameFilter(selfilter);
-    fileDlg.selectNameFilter(selfilter);
-    fileDlg.setObjectName("fileDialogAdd");
-    if (DFileDialog::Accepted == fileDlg.exec()) {
-        m_lastImportPath = fileDlg.directory().path();
-        QStringList fileList = fileDlg.selectedFiles();
-
-        qint64 bytes = 0;
-        foreach(QString filePath, fileList) {
-            QFile file(filePath);
-            if (file.exists()) {
-                QFileInfo fileInfo(file);
-                bytes += fileInfo.size();
-            }
-        }
-        if ((bytes + m_allFileSize) > (KnowledgeBaseSize)) {
-            //知识库容量不足
-            DDialog dialog(QObject::tr("Insufficient knowledge base capacity")
-                           , QObject::tr("The total capacity of the knowledge base is %1M, with a remaining %2. "
-                                         "The total number of files added this time is %3. Unable to complete the add to knowledge base operation.")
-                           .arg(1024).arg(formatSize(KnowledgeBaseSize - m_allFileSize)).arg(formatSize(bytes)));
-            dialog.setIcon(QIcon(":assets/images/warning.svg"));
-            dialog.addButton(QObject::tr("OK", "button"));
-            int ret = dialog.exec();
-            return;
-        }
-
-        qint64 diskSpaceSize = getDiskSpace(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation));
-        //diskSpaceSize = 1024;
-        if ((bytes) > diskSpaceSize) {
-            //磁盘容量不足
-            DDialog dialog(tr("Not enough disk space") ,
-                           tr("To store the newly added files, at least %1 of disk space is required. The current remaining space is %2. "
-                              "Please clear enough hard disk space and try again.").arg(formatSize(bytes)).arg(formatSize(diskSpaceSize)));
-            dialog.setIcon(QIcon(":assets/images/warning.svg"));
-            dialog.addButton(QObject::tr("OK", "button"));
-            int ret = dialog.exec();
-            return;
-        }
-
-        bool appendRet = onAppendKnowledgeBase(fileList);
-
-        for (const QString &file : fileList) {
-            if (appendRet && !EmbeddingServer::getInstance().createVectorIndex(QStringList(file)))
-                return;
+        QFileInfo fileInfo(filePath);
+        QString fileName = fileInfo.fileName();
+        KnowledgeBaseItem *item = m_pHasKnowledgeBaseWidget->findChild<KnowledgeBaseItem *>("KnowledgeBaseItem_" + fileName);
+        if (item) {
+            // 存在-刷新状态
+            item->setStatus(knowStatus);
+            item->setFilePath(filePath);
+            continue;
         }
     }
 }
 
-void KnowledgeBaseListWidget::onAddToServerStatusChanged(const QStringList &files, int status)
+void KnowledgeBaseListWidget::refreshKnowBaseListOld(const QStringList &files, int status)
 {
+    qCDebug(logAIGUI) << "Refreshing knowledge base list (old). Files:" << files << ", Status:" << status;
     qDebug() << "onAddToServerStatusChanged: " << files << "   status: " << status;
-    QStringList docFiles = EmbeddingServer::getInstance().getDocFiles();
+    QVector<QPair<int, QString>> docFiles = KnowledgeBaseManager::getInstance().getKnowledgeBaseFiles();
 
     foreach(QString file, files) {
         QFileInfo fileInfo(file);
@@ -352,14 +441,17 @@ void KnowledgeBaseListWidget::onAddToServerStatusChanged(const QStringList &file
             return;
 
         switch (status) {
-        case 0: //失败
+        case -1: //文件错误
+            item->setStatus(KnowledgeBaseProcessStatus::FileError);
+            break;
+        case -2: //数据错误
             item->setStatus(KnowledgeBaseProcessStatus::ProcessingError);
             break;
         case 1: //成功
             item->setStatus(KnowledgeBaseProcessStatus::Succeed);
-            foreach(QString docFile, docFiles) {
-                if (docFile.contains(fileName)) {
-                    item->setFilePath(docFile);
+            foreach(auto docFile, docFiles) {
+                if (docFile.second.contains(fileName)) {
+                    item->setFilePath(docFile.second);
                     break;
                 }
             }
@@ -381,62 +473,12 @@ void KnowledgeBaseListWidget::onAddToServerStatusChanged(const QStringList &file
                 break;
             }
         }
-        if (!hasProcessing)
-            emit sigGenPersonalFAQ();
     }
 }
 
-void KnowledgeBaseListWidget::onIndexDeleted(const QStringList &files)
-{
-    foreach(QString file, files) {
-        QFileInfo fileInfo(file);
-        KnowledgeBaseItem *item = m_pHasKnowledgeBaseWidget->findChild<KnowledgeBaseItem *>("KnowledgeBaseItem_" + fileInfo.fileName());
-        if (!item)
-            continue;
-
-        updateFileSize(-item->fileSize());
-        m_pHasKnowledgeBaseWidget->layout()->removeWidget(item);
-        item->setParent(nullptr);
-        delete item;
-
-        adjustWidgetSize();
-    }
-}
-
-bool KnowledgeBaseListWidget::eventFilter(QObject *watched, QEvent *event)
-{
-    if (event->type() == QEvent::Enter) {
-        if (watched == m_tipIconLabel) {
-            QPoint p = mapToGlobal(m_tipIconLabel->pos());
-            showTips(p.x() + 20, p.y() + 15);
-        }
-    } else if (event->type() == QEvent::Leave) {
-        if (watched == m_tipIconLabel) {
-            hideTips();
-        }
-
-    }
-    return DWidget::eventFilter(watched, event);
-}
-
-void KnowledgeBaseListWidget::adjustWidgetSize()
-{
-    if (m_pHasKnowledgeBaseWidget->layout()->count() <= 0) {
-        m_pNoKnowledgeBaseWidget->show();
-        m_pHasKnowledgeBaseWidget->hide();
-        m_pDeleteButton->hide();
-        m_pDeleteButton->setProperty("editMode", false);
-        m_pAddButton->setEnabled(true);
-    } else {
-        m_pNoKnowledgeBaseWidget->hide();
-        m_pHasKnowledgeBaseWidget->show();
-        m_pDeleteButton->show();
-    }
-    adjustSize();
-}
-
 void KnowledgeBaseListWidget::resetEditButton()
 {
+    qCDebug(logAIGUI) << "Resetting edit button.";
     if (m_pDeleteButton->property("editMode").toBool()) {
         onEditButtonClicked();
     }
@@ -444,6 +486,7 @@ void KnowledgeBaseListWidget::resetEditButton()
 
 void KnowledgeBaseListWidget::updateDocStatus(QString &name, KnowledgeBaseProcessStatus status)
 {
+    qCDebug(logAIGUI) << "Updating doc status. Name:" << name << ", Status:" << status;
     KnowledgeBaseItem *item = m_pHasKnowledgeBaseWidget->findChild<KnowledgeBaseItem *>("KnowledgeBaseItem_" + name);
     if (item) {
         item->setStatus(status);
@@ -452,6 +495,7 @@ void KnowledgeBaseListWidget::updateDocStatus(QString &name, KnowledgeBaseProces
 
 void KnowledgeBaseListWidget::updateFileSize(qint64 bytes)
 {
+    qCDebug(logAIGUI) << "Updating file size. Delta:" << bytes << ", New total:" << (m_allFileSize + bytes);
     m_allFileSize += bytes;
     m_sizeLabel->setText(QString("%1/1024M").arg(formatSize(m_allFileSize)));
 }
@@ -459,28 +503,45 @@ void KnowledgeBaseListWidget::updateFileSize(qint64 bytes)
 QString KnowledgeBaseListWidget::formatSize(qint64 bytes)
 {
     QString str = "-1B";
-
-    if (bytes < 1024)
-        str = QString("%1B").arg(bytes);
-    else if (bytes < 1024 * 1024)
+    if (bytes < 1024 * 1024)
         str =  QString("%1KB").arg(bytes / 1024.0, 0, 'f', 1);
     else
         str =  QString("%1M").arg(bytes / (1024.0 * 1024.0), 0, 'f', 1);
 
-    return str;
+    //正则表达去掉小数点后为.0的情况
+    QRegularExpression regExp(R"(\.0(?=[kmBKMG]))");
+    QRegularExpressionMatch match = regExp.match(str);
+
+    if (match.hasMatch()) {
+        // 替换掉匹配的 ".0" 部分
+        return str.replace(match.captured(0), "");
+    } else {
+        // 如果没有找到匹配的 ".0"，则返回原字符串
+        return str;
+    }
 }
 
 qint64 KnowledgeBaseListWidget::getDiskSpace(const QString &mountPoint)
 {
     QProcess process;
-    QString command = "df " + mountPoint; //单位是KB
-    process.start(command);
+    QStringList arguments;
+    arguments << mountPoint;
+    process.start("df", arguments);
     process.waitForFinished();
 
     QString output = process.readAllStandardOutput();
+    QStringList fields;
+
+#ifdef COMPILE_ON_QT6
+    QStringList lines = output.split(QRegularExpression("\\n"), Qt::SkipEmptyParts);
+    if (lines.size() > 1)
+        fields = lines.at(1).split(QRegularExpression("\\s+"), Qt::SkipEmptyParts);
+#else
     QStringList lines = output.split(QRegExp("\\n"), QString::SkipEmptyParts);
+    if (lines.size() > 1)
+        fields = lines.at(1).split(QRegExp("\\s+"), QString::SkipEmptyParts);
+#endif
 
-    QStringList fields = lines.at(1).split(QRegExp("\\s+"), QString::SkipEmptyParts);
     if (fields.size() >= 5) {
         // 通常df的输出格式是：文件系统 容量 已用 可用 已用% 挂载点
         return fields.at(3).toLongLong() * 1024;
@@ -491,29 +552,46 @@ qint64 KnowledgeBaseListWidget::getDiskSpace(const QString &mountPoint)
 
 void KnowledgeBaseListWidget::showTips(int x, int y)
 {
+    qCDebug(logAIGUI) << "Showing tips at position:" << QPoint(x, y);
     if (!m_tips) {
-        m_tips = new DLabel();
-        m_tips->setText(tr("This feature requires high hardware resources, and the reference benchmark configuration is: CPU Intel 11th generation i7 or above; "
-                           "Memory of 16GB or more; Having a NVIDIA graphics card and a 10 series or higher is the best option. "
-                           "If the configuration is too low, there may be issues such as lagging and inaccurate answers."));
+        m_tips = new DTipLabel(tr("This feature requires high hardware resources, and the reference benchmark configuration is: CPU Intel 11th generation i7 or above; "
+                                  "Memory of 16GB or more; Having a NVIDIA graphics card and a 10 series or higher is the best option. "
+                                  "If the configuration is too low, there may be issues such as lagging and inaccurate answers."));
         m_tips->setWordWrap(true);
         m_tips->setFixedWidth(320);
         m_tips->setContentsMargins(20, 15, 17, 15);
-        QPalette pl = m_tips->palette();
-        pl.setColor(QPalette::Text, DGuiApplicationHelper::instance()->applicationPalette().color(QPalette::Text));
-        m_tips->setPalette(pl);
-        m_tips->setForegroundRole(QPalette::Text);
         m_tips->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
-        m_tips->setWindowFlags(Qt::FramelessWindowHint | Qt::Tool | Qt::Window);
-        m_tips->setForegroundRole(DPalette::TextTitle);
+        m_tips->setForegroundRole(DPalette::NoType);
         DFontSizeManager::instance()->bind(m_tips, DFontSizeManager::T8, QFont::Medium);
-
-        m_tips->move(x, y);
-        m_tips->show();
-    } else {
-        m_tips->move(x, y);
-        m_tips->show();
     }
+
+    DPalette pa = m_tips->palette();
+    if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
+        pa.setColor(QPalette::WindowText, QColor(0, 0, 0, 255));
+    } else {
+        pa.setColor(QPalette::WindowText, QColor(255, 255, 255, 255 * 0.7));
+    }
+    m_tips->setPalette(pa);
+
+    m_tips->adjustSize();
+
+    QRect tipsRect = QRect(QPoint(x, y), m_tips->size());
+    for (QScreen *screen : QGuiApplication::screens()) {
+        QRect screenRect = screen->geometry();
+        if (screenRect.contains(tipsRect))
+            break;
+        else if (screenRect.intersects(tipsRect)) {
+            if (tipsRect.right() > screenRect.right()) {
+                x -= (m_tips->width() + 20);
+            }
+            if (tipsRect.bottom() > screenRect.bottom()) {
+                y -= m_tips->height();
+            }
+            break;
+        }
+    }
+
+    m_tips->show(QPoint(x, y));
 }
 void KnowledgeBaseListWidget::hideTips()
 {
@@ -521,3 +599,14 @@ void KnowledgeBaseListWidget::hideTips()
         m_tips->hide();
 }
 
+QString KnowledgeBaseListWidget::getTitleName()
+{
+    return m_pWidgetLabel->text();
+}
+
+bool KnowledgeBaseListWidget::checkEmbeddingPluginsStatus()
+{
+    //通过toolTip判断当前向量化插件安装情况
+    return m_pAddButton->toolTip().isEmpty();
+}
+
