@@ -6,7 +6,7 @@
 #include "wrapcheckbox.h"
 #include "private/echatwndmanager.h"
 #include "utils/esystemcontext.h"
-#include "../chat/private/eaiexecutor.h"
+#include "private/eaiexecutor.h"
 #include "utils/util.h"
 
 #include <DTitlebar>
@@ -15,11 +15,17 @@
 #include <DDialog>
 #include <DPaletteHelper>
 
+#include <QScreen>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
 #include <QTimer>
 #include <QUuid>
 #include <QApplication>
+#include <QLoggingCategory>
+
+UOSAI_USE_NAMESPACE
+
+Q_DECLARE_LOGGING_CATEGORY(logAIGUI)
 
 static constexpr char info[] = "uos-ai-assistant_info";
 static constexpr char WARNING_ICON[] = ":/assets/images/warning.svg";
@@ -50,7 +56,8 @@ WelcomeDialog *WelcomeDialog::instance(bool onlyUseAgreement)
 
 void WelcomeDialog::initUI()
 {
-    setFixedWidth(400);
+    int dialogWidth = 460;
+    setFixedWidth(dialogWidth);
     //标题栏
     DTitlebar *titleBar = new DTitlebar(this);
     titleBar->setMenuVisible(false);
@@ -62,33 +69,31 @@ void WelcomeDialog::initUI()
     ThemedLable *titleLable = new ThemedLable(tr("Welcome to UOS AI"));
     titleLable->setPaletteColor(QPalette::Text, QPalette::BrightText, 0.9);
     titleLable->setAlignment(Qt::AlignCenter);
-    titleLable->setFixedWidth(300);
+    titleLable->setFixedWidth(dialogWidth * 0.75);
     DFontSizeManager::instance()->bind(titleLable, DFontSizeManager::T3, QFont::Medium);
 
     m_pIntroduce = new ThemedLable(tr("UOS AI, your smart assistant, is designed to improve your productivity and enjoy a high-quality work experience."));
     m_pIntroduce->setPaletteColor(QPalette::Text, DPalette::BrightText, 0.7);
-    m_pIntroduce->setFixedWidth(300);
+    m_pIntroduce->setFixedWidth(dialogWidth * 0.75);
     m_pIntroduce->setAlignment(Qt::AlignCenter);
     m_pIntroduce->setWordWrap(true);
     DFontSizeManager::instance()->bind(m_pIntroduce, DFontSizeManager::T5, QFont::Normal);
 
     auto labelLayout = new QHBoxLayout();
     labelLayout->setContentsMargins(50, 0, 50, 0);
-    labelLayout->addWidget(m_pIntroduce, 0, Qt::AlignCenter);
-    labelLayout->addStretch();
+    labelLayout->addWidget(m_pIntroduce, 1, Qt::AlignCenter);
 
     m_pAgrCheckbox = new WrapCheckBox();
     m_pAgrCheckbox->setTextFormat(Qt::RichText);
     m_pAgrCheckbox->setTextInteractionFlags(Qt::LinksAccessibleByMouse);
     m_pAgrCheckbox->setOpenExternalLinks(true);
-    m_pAgrCheckbox->setTextMaxWidth(330);
-    m_pAgrCheckbox->setFixedWidth(360);
+    m_pAgrCheckbox->setTextMaxWidth(dialogWidth - 80);
+    m_pAgrCheckbox->setFixedWidth(dialogWidth - 40);
     m_pAgrCheckbox->setFontSize(DFontSizeManager::T7, QFont::Normal);
 
     auto agrLayout = new QHBoxLayout();
     agrLayout->setContentsMargins(20, 0, 20, 0);
-    agrLayout->addWidget(m_pAgrCheckbox, 0, Qt::AlignTop | Qt::AlignLeft);
-    agrLayout->addStretch();
+    agrLayout->addWidget(m_pAgrCheckbox, 1, Qt::AlignTop | Qt::AlignLeft);
 
     m_pFreeAccount = new DSuggestButton();
     m_pFreeAccount->setFixedSize(360, 36);
@@ -98,15 +103,14 @@ void WelcomeDialog::initUI()
     m_pActivity->setTextFormat(Qt::RichText);
     m_pActivity->setTextInteractionFlags(Qt::LinksAccessibleByMouse);
     m_pActivity->setOpenExternalLinks(true);
-    m_pActivity->setFixedWidth(360);
+    m_pActivity->setFixedWidth(dialogWidth - 40);
     m_pActivity->setAlignment(Qt::AlignCenter);
     m_pActivity->setWordWrap(true);
     DFontSizeManager::instance()->bind(m_pActivity, DFontSizeManager::T10, QFont::Medium);
 
     auto activityLabelLayout = new QHBoxLayout();
     activityLabelLayout->setContentsMargins(20, 0, 20, 0);
-    activityLabelLayout->addWidget(m_pActivity, 0, Qt::AlignCenter);
-    activityLabelLayout->addStretch();
+    activityLabelLayout->addWidget(m_pActivity, 1, Qt::AlignCenter);
 
     m_pFreeWidget = new DWidget();
     auto freeLayout = new QVBoxLayout(m_pFreeWidget);
@@ -137,14 +141,14 @@ void WelcomeDialog::initUI()
     mainLayout->addWidget(titleLable, 0, Qt::AlignHCenter);
     mainLayout->addSpacing(10);
     mainLayout->addLayout(labelLayout);
-    mainLayout->addSpacing(100);
+    m_pVerticalSpacer = new QSpacerItem(0, 100, QSizePolicy::Minimum, QSizePolicy::Fixed);
+    mainLayout->addSpacerItem(m_pVerticalSpacer);
     mainLayout->addStretch();
     mainLayout->addLayout(agrLayout);
     mainLayout->addSpacing(20);
     mainLayout->addWidget(m_pStartUsing, 0, Qt::AlignHCenter);
     mainLayout->addWidget(m_pFreeWidget);
     mainLayout->addWidget(m_pAddModel, 0, Qt::AlignHCenter);
-    //mainLayout->addStretch();
     this->setLayout(mainLayout);
 
     resetLinkColor();
@@ -160,10 +164,7 @@ void WelcomeDialog::initConnect()
 
     connect(m_pAddModel, &DPushButton::clicked, this, [this ](int state) {
         updateAgree();
-        QTimer::singleShot(1, this, []{
-            QCoreApplication::processEvents();
-            EAiExec()->launchLLMConfigWindow(false);
-        });
+        emit signalShowMgmtWindowAfterChatInitFinished();
     });
 
     connect(m_pAddModel, &DPushButton::clicked, this, &WelcomeDialog::accept);
@@ -184,9 +185,25 @@ void WelcomeDialog::onUpdateSystemFont(const QFont &)
     heightDiff += m_pIntroduce->sizeHint().height() - m_pIntroduce->height();
     heightDiff += m_pAgrCheckbox->sizeHint().height() - m_pAgrCheckbox->height();
     heightDiff += m_pActivity->sizeHint().height() - m_pActivity->height();
-    if(heightDiff > 0)
-        this->setFixedHeight(this->height() + heightDiff + 50);
-    else {
+    if(heightDiff > 0) {
+        int height = this->height() + heightDiff + 50;
+        if (auto screen = QGuiApplication::primaryScreen()) {
+            const int screenHeight = screen->availableGeometry().height();
+            if (height > screenHeight) {
+                const int overflow = height - screenHeight;
+                if (m_pVerticalSpacer) {
+                    m_pVerticalSpacer->changeSize(0, 100 - overflow, QSizePolicy::Minimum, QSizePolicy::Fixed);
+                    layout()->invalidate();
+                }
+                height = screenHeight;
+            } else {
+                if (m_pVerticalSpacer) {
+                    m_pVerticalSpacer->changeSize(0, 0, QSizePolicy::Minimum, QSizePolicy::Fixed);
+                }
+            }
+        }
+        this->setFixedHeight(height);
+    } else {
         this->setMinimumHeight(0);
         this->setMaximumWidth(QWIDGETSIZE_MAX);
     }
@@ -217,14 +234,16 @@ void WelcomeDialog::resetLinkColor()
 void WelcomeDialog::updateAgree()
 {
     if (m_pAgrCheckbox->isEnabled()) {
-        DbWrapper::localDbWrapper().updateAICopilot(
-                    m_pAgrCheckbox->checkState() == Qt::Unchecked ? false : true);
+        bool agreed = m_pAgrCheckbox->checkState() != Qt::Unchecked;
+        DbWrapper::localDbWrapper().updateAICopilot(agreed);
+        qCInfo(logAIGUI) << "User agreement status updated:" << agreed;
 
         // 使用欢迎界面后无需再提示新手引导。
         {
             auto cur = DbWrapper::localDbWrapper().getGuideKey();
             if (cur.isEmpty() || cur.toInt() < DbWrapper::builtinGuideVersion()) {
                 DbWrapper::localDbWrapper().updateGuideKey(QString::number(DbWrapper::builtinGuideVersion()));
+                qCDebug(logAIGUI) << "Guide version updated to:" << DbWrapper::builtinGuideVersion();
             }
         }
     }
@@ -237,6 +256,7 @@ bool WelcomeDialog::isFreeAccount()
 
 void WelcomeDialog::onGetFreeAccount()
 {
+    qCDebug(logAIGUI) << "Requesting free account";
     m_pFreeAccount->setDisabled(true);
 
     DDialog dlg(this);
@@ -249,6 +269,7 @@ void WelcomeDialog::onGetFreeAccount()
 
     m_pFreeAccount->setDisabled(false);
     if (QNetworkReply::NoError == error) {
+        qCInfo(logAIGUI) << "Free account received successfully";
         m_freeAccount = true;
 
         LLMServerProxy llm;
@@ -267,12 +288,14 @@ void WelcomeDialog::onGetFreeAccount()
         llm.account = accountProxy;
 
         if (!DbWrapper::localDbWrapper().appendLlm(llm)) {
+            qCWarning(logAIGUI) << "Failed to save free account configuration";
             dlg.setMessage(tr("Save failed, please try again later"));
             dlg.addButton(tr("Confirm", "button"), true, DDialog::ButtonNormal);
             dlg.exec();
             return;
         }
 
+        qCInfo(logAIGUI) << "Free account configuration saved successfully";
         ServerWrapper::instance()->updateLLMAccount();
         emit signalAppendModel(llm);
         dlg.setTitle(tr("Trial account received successfully."));// UOS AI试用账号领取成功！
@@ -287,6 +310,7 @@ void WelcomeDialog::onGetFreeAccount()
         updateAgree();
         accept();
     } else if (1 == status) {
+        qCInfo(logAIGUI) << "Free account activity has ended";
         dlg.setMessage(tr("The free account activity ends."));
         dlg.addButton(tr("Confirm", "button"), true, DDialog::ButtonNormal);
         dlg.exec();
@@ -294,6 +318,7 @@ void WelcomeDialog::onGetFreeAccount()
         m_pFreeWidget->hide();
         this->adjustSize();
     } else {
+        qCWarning(logAIGUI) << "Failed to connect to server for free account, error:" << error << "status:" << status;
         dlg.setMessage(tr("Unable to connect to the server, please check your network or try again later."));
         dlg.addButton(tr("Confirm", "button"), true, DDialog::ButtonNormal);
         dlg.exec();
@@ -335,6 +360,7 @@ void WelcomeDialog::resetDialog()
 
     {
         bool agreed = isAgreed();
+        qCDebug(logAIGUI) << "Current agreement status:" << agreed;
         m_pAgrCheckbox->setCheckState(agreed ? Qt::Checked : Qt::Unchecked);
         if (agreed)
             m_pAgrCheckbox->setDisabled(true);
