@@ -5,6 +5,9 @@
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QJsonArray>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logLLM)
 
 Gpt360::Gpt360(const LLMServerProxy &serverproxy)
     : LLM(serverproxy)
@@ -23,6 +26,9 @@ QString Gpt360::modelId()
 
 QJsonObject Gpt360::predict(const QString &content, const QJsonArray &functions)
 {
+    qCInfo(logLLM) << "360 Starting prediction with content length:" << content.length()
+                   << "and" << functions.size() << "functions";
+
     Conversation360 conversion;
     conversion.addUserData(content);
     conversion.setFunctions(functions);
@@ -30,8 +36,10 @@ QJsonObject Gpt360::predict(const QString &content, const QJsonArray &functions)
     QString systemRole = m_params.value(PREDICT_PARAM_SYSTEMROLE).toString();
     qreal temperature = m_params.value(PREDICT_PARAM_TEMPERATURE, 1.0).toReal();
 
-    if (!systemRole.isEmpty())
+    if (!systemRole.isEmpty()) {
+        qCDebug(logLLM) << "360 Setting system role.";
         conversion.setSystemData(systemRole);
+    }
 
     ChatCompletion360 chatCompletion(m_accountProxy.account);
     connect(this, &Gpt360::aborted, &chatCompletion, &ChatCompletion360::requestAborted);
@@ -41,11 +49,17 @@ QJsonObject Gpt360::predict(const QString &content, const QJsonArray &functions)
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
+    if (errorpair.first != 0) {
+        qCWarning(logLLM) << "360 Prediction failed with error:" << errorpair.first 
+                         << "-" << errorpair.second;
+    }
+
     QJsonObject response;
     response["content"] = conversion.getLastResponse();
 
     QJsonObject tools = conversion.getLastTools();
     if (!tools.isEmpty()) {
+        qCDebug(logLLM) << "360 Prediction returned tools response";
         response["tools"] = tools;
     }
     return response;
@@ -53,6 +67,7 @@ QJsonObject Gpt360::predict(const QString &content, const QJsonArray &functions)
 
 QPair<int, QString> Gpt360::verify()
 {
+    qCDebug(logLLM) << "360 Starting account verification";
     Conversation360 conversion;
     conversion.addUserData("Account verification only, no need for any response.");
 
@@ -63,12 +78,21 @@ QPair<int, QString> Gpt360::verify()
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
+    if (errorpair.first != 0)
+        qCWarning(logLLM) << "360 Account verification failed with error:" << errorpair.first
+                         << "-" << errorpair.second;
+
     return errorpair;
 }
 
 void Gpt360::onReadyReadChatDeltaContent(const QByteArray &content)
 {
-    if (content.isEmpty() || !stream())
+    if (content.isEmpty())
+        return;
+
+    m_replied = true;
+
+    if (!stream())
         return;
 
     QString deltacontent = Conversation360::parseContentString(content);
