@@ -6,6 +6,9 @@
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QJsonArray>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logLLM)
 
 WXQFAI::WXQFAI(const LLMServerProxy &serverproxy)
     : LLM(serverproxy)
@@ -15,6 +18,9 @@ WXQFAI::WXQFAI(const LLMServerProxy &serverproxy)
 
 QJsonObject WXQFAI::predict(const QString &content, const QJsonArray &functions)
 {
+    qCInfo(logLLM) << "WXQFAI Starting prediction with content length:" << content.length()
+                         << "and" << functions.size() << "functions";
+    
     WXQFConversation conversion;
     conversion.addUserData(content);
     conversion.setFunctions(functions);
@@ -29,11 +35,15 @@ QJsonObject WXQFAI::predict(const QString &content, const QJsonArray &functions)
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
+    if (errorpair.first != 0)
+        qCWarning(logLLM) << "WXQFAI Prediction failed with error:" << errorpair.first << errorpair.second;
+
     QJsonObject response;
     response["content"] = conversion.getLastResponse();
 
     QJsonObject tools = conversion.getLastTools();
     if (!tools.isEmpty()) {
+        qCDebug(logLLM) << "WXQFAI Prediction returned tools response";
         response["tools"] = tools;
     }
     return response;
@@ -41,6 +51,8 @@ QJsonObject WXQFAI::predict(const QString &content, const QJsonArray &functions)
 
 QList<QByteArray> WXQFAI::text2Image(const QString &prompt, int number)
 {
+    qCInfo(logLLM) << "WXQFAI Starting text2Image with prompt length:" << prompt.length() << "and number:" << number;
+    
     WXQFText2Image textToImage(m_accountProxy.account);
     connect(this, &WXQFAI::aborted, &textToImage, &WXQFText2Image::requestAborted);
 
@@ -49,11 +61,19 @@ QList<QByteArray> WXQFAI::text2Image(const QString &prompt, int number)
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
+    if (errorpair.first != 0) {
+        qCWarning(logLLM) << "WXQFAI text2Image failed with error:" << errorpair.first << errorpair.second;
+    } else {
+        qCDebug(logLLM) << "WXQFAI text2Image completed successfully, generated" << imageData.size() << "images";
+    }
+
     return imageData;
 }
 
 QPair<int, QString> WXQFAI::verify()
 {
+    qCDebug(logLLM) << "WXQFAI Starting account verification";
+    
     WXQFConversation conversion;
     conversion.addUserData("Account verification only, no need for any response.");
 
@@ -64,16 +84,26 @@ QPair<int, QString> WXQFAI::verify()
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
+    if (errorpair.first != 0) {
+        qCWarning(logLLM) << "WXQFAI Account verification failed with error:" << errorpair.first << errorpair.second;
+    } else {
+        qCDebug(logLLM) << "WXQFAI Account verification completed successfully";
+    }
+
     return errorpair;
 }
 
 void WXQFAI::onReadyReadChatDeltaContent(const QByteArray &content)
 {
-    if (content.isEmpty() || !stream())
+    if (content.isEmpty())
+        return;
+
+    m_replied = true;
+
+    if (!stream())
         return;
 
     QJsonObject deltacontent = m_deltaConversion->parseContentString(content);
-
     if (deltacontent.contains("content")) {
         textChainContent(deltacontent.value("content").toString());
     }
