@@ -4,6 +4,9 @@
 #include <QJsonObject>
 #include <QJsonArray>
 #include <QStandardPaths>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logLLM)
 
 WXQFChatCompletion::WXQFChatCompletion(const AccountProxy &account)
     : WXQFNetWork(account)
@@ -17,6 +20,7 @@ QPair<int, QString> WXQFChatCompletion::create(int model, const QString &url, WX
     QJsonArray conversions = conversation.getConversions();
     if (!conversation.getFunctions().isEmpty()) {
         dataObject.insert("functions", conversation.getFunctions());
+        qCDebug(logLLM) << "WXQF Added functions to request";
     }
 
     dataObject.insert("messages", conversions);
@@ -41,11 +45,13 @@ QPair<int, QString> WXQFChatCompletion::create(int model, const QString &url, WX
         modelUrl = rootPath + path;
     }
 
-    qInfo() << "baidu request url:" << modelUrl;
+    qCInfo(logLLM) << "WXQF Requesting API with URL:" << modelUrl;
     const QPair<int, QByteArray> &resultPairs = request(dataObject, modelUrl);
 
-    if (resultPairs.first != 0)
+    if (resultPairs.first != 0) {
+        qCWarning(logLLM) << "WXQF Request failed with error code:" << resultPairs.first;
         return qMakePair(resultPairs.first, resultPairs.second);
+    }
 
     conversation.update(resultPairs.second);
     return qMakePair(0, QString());
