@@ -16,6 +16,8 @@
 
 #define PREDICT_PARAM_NOJSONOUTPUT "onJsonOutput"  // only send content not json format in dbus session
 
+#define PREDICT_PARAM_MCPSERVERS "mcpServers"  // what mcp servers need to use.
+
 class LLM : public QObject
 {
     Q_OBJECT
@@ -61,6 +63,7 @@ public:
     QString lastErrorString();
     void setLastErrorString(const QString &errorMessage);
 
+    virtual bool isReplied() const;
 signals:
     /**
      * @brief This signal is emitted when the task has been cancelled.
@@ -101,7 +104,9 @@ public:
 
 protected:
     void readyThinkChainContent(const QJsonObject &content);
-    bool startThink = false;
+
+protected:
+    bool m_replied = false;
     QVariantHash m_params;
 
     LLMServerProxy m_accountProxy;
