@@ -5,7 +5,7 @@
 
 QString ParseRspPrompt::perfectString(QString data)
 {
-    return data.remove(QRegExp("[\"]"));
+    return data.remove(QRegularExpression("[\"]"));
 }
 
 QMap<QString, QVariantMap> ParseRspPrompt::chatCmdPromptResponse(const QString &response, const QMap<QString, QVariantMap> &srcAppCmdPrompts)
@@ -31,9 +31,5 @@ QMap<QString, QVariantMap> ParseRspPrompt::chatCmdPromptResponse(const QString &
         }
     }
 
-    if (appCmdPrompts.isEmpty()) {
-        qWarning() << "ResponseParser::parseChatCmdPromptResponse error = " << response;
-    }
-
     return appCmdPrompts;
 }
