@@ -1,4 +1,7 @@
 #include "aiimages.h"
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logLLM)
 
 #include <QJsonDocument>
 #include <QJsonObject>
@@ -17,8 +20,10 @@ QList<QByteArray> AIImages::parserImages(const QByteArray &data) const
 {
     QList<QByteArray> imageData;
     const QJsonArray &datas = QJsonDocument::fromJson(data).object().value("data").toArray();
+    qCDebug(logLLM) << "AIImages Parsing images data, array size:" << datas.size();
+    
     for (int i = 0; i < datas.size(); i++) {
-        const QByteArray &data = QByteArray::fromBase64(datas.at(i).toObject().value("b64_json").toVariant().toByteArray());
+        const QByteArray &data = datas.at(i).toObject().value("b64_json").toString().toUtf8();
         imageData << data;
     }
     return imageData;
@@ -26,6 +31,8 @@ QList<QByteArray> AIImages::parserImages(const QByteArray &data) const
 
 QPair<int, QString> AIImages::create(const QString &prompt, QList<QByteArray> &imageData, int n, const QString &size, const QString &format)
 {
+    qCDebug(logLLM) << "AIImages Creating images with prompt:" << prompt << "n:" << n << "size:" << size << "format:" << format;
+
     QJsonObject dataObject;
     dataObject.insert("prompt", prompt);
     dataObject.insert("n", qBound(1, n, 4));
@@ -33,8 +40,10 @@ QPair<int, QString> AIImages::create(const QString &prompt, QList<QByteArray> &i
     dataObject.insert("response_format", format);
 
     const QPair<int, QByteArray> &resultPairs = request(dataObject, "/images/generations");
-    if (resultPairs.first != 0)
+    if (resultPairs.first != 0) {
+        qCWarning(logLLM) << "AIImages Image generation request failed with error:" << resultPairs.first;
         return qMakePair(resultPairs.first, resultPairs.second);
+    }
 
     imageData = parserImages(resultPairs.second);
     return qMakePair(0, QString());
