@@ -6,6 +6,9 @@
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QJsonArray>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logLLM)
 
 ChatGpt::ChatGpt(const LLMServerProxy &serverproxy)
     : LLM(serverproxy)
@@ -27,6 +30,9 @@ QString ChatGpt::modelId()
 
 QJsonObject ChatGpt::predict(const QString &content, const QJsonArray &functions)
 {
+    qCInfo(logLLM) << "ChatGpt Starting prediction with content length:" << content.length() 
+                   << "and" << functions.size() << "functions";
+    
     AIConversation conversion;
     conversion.addUserData(content);
     conversion.setFunctions(functions);
@@ -34,8 +40,10 @@ QJsonObject ChatGpt::predict(const QString &content, const QJsonArray &functions
     QString systemRole = m_params.value(PREDICT_PARAM_SYSTEMROLE).toString();
     qreal temperature = m_params.value(PREDICT_PARAM_TEMPERATURE, 1.0).toReal();
 
-    if (!systemRole.isEmpty())
+    if (!systemRole.isEmpty()) {
+        qCDebug(logLLM) << "ChatGpt Setting system role for prediction";
         conversion.setSystemData(systemRole);
+    }
 
     AIChatCompletion chatCompletion(m_accountProxy.account);
     connect(this, &ChatGpt::aborted, &chatCompletion, &AIChatCompletion::requestAborted);
@@ -83,6 +91,7 @@ QJsonObject ChatGpt::predict(const QString &content, const QJsonArray &functions
 
     QJsonObject tools = conversion.getLastTools();
     if (!tools.isEmpty()) {
+        qCDebug(logLLM) << "ChatGpt Prediction returned tools response";
         response["tools"] = tools;
     }
     return response;
@@ -90,11 +99,23 @@ QJsonObject ChatGpt::predict(const QString &content, const QJsonArray &functions
 
 QList<QByteArray> ChatGpt::text2Image(const QString &prompt, int number)
 {
+    qCDebug(logLLM) << "Starting text2image with prompt length:" << prompt.length()
+                   << "and image count:" << number;
+
     AIImages textToImage(m_accountProxy.account);
     connect(this, &ChatGpt::aborted, &textToImage, &AIImages::requestAborted);
 
     QList<QByteArray> imageData;
     QPair<int, QString> errorpair = textToImage.create(prompt, imageData, number);
+    
+    if (errorpair.first != 0) {
+        qCWarning(logLLM) << "Text2Image failed with error:" << errorpair.first
+                         << "-" << errorpair.second;
+    } else {
+        qCDebug(logLLM) << "Text2Image completed successfully, generated" 
+                       << imageData.size() << "images";
+    }
+
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
@@ -103,6 +124,8 @@ QList<QByteArray> ChatGpt::text2Image(const QString &prompt, int number)
 
 QPair<int, QString> ChatGpt::verify()
 {
+    qCDebug(logLLM) << "Starting account verification";
+
     AIConversation conversion;
     conversion.addUserData("Account verification only, no need for any response.");
 
@@ -110,6 +133,14 @@ QPair<int, QString> ChatGpt::verify()
     connect(this, &ChatGpt::aborted, &chatCompletion, &AIChatCompletion::requestAborted);
 
     QPair<int, QString> errorpair = chatCompletion.create(modelId(), conversion);
+    
+    if (errorpair.first != 0) {
+        qCWarning(logLLM) << "Account verification failed with error:" << errorpair.first
+                         << "-" << errorpair.second;
+    } else {
+        qCDebug(logLLM) << "Account verification successful";
+    }
+
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
@@ -118,8 +149,14 @@ QPair<int, QString> ChatGpt::verify()
 
 void ChatGpt::onReadyReadChatDeltaContent(const QByteArray &content)
 {
-    if (content.isEmpty() || !stream())
+    if (content.isEmpty())
         return;
+
+    m_replied = true;
+
+    if (!stream())
+        return;
+
     const QJsonObject &deltacontent = AIConversation::parseContentString(content);
 
 #ifdef OpenTextAuditService
