@@ -11,6 +11,9 @@
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QJsonArray>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logLLM)
 
 UOSAI_USE_NAMESPACE
 
@@ -21,6 +24,7 @@ UniversalAPI::UniversalAPI(const LLMServerProxy &serverproxy) : LLM(serverproxy)
 
 QPair<int, QString> UniversalAPI::verify()
 {
+    qCDebug(logLLM) << "UniversalAPI Starting account verification";
     AIConversation conversion;
     conversion.addUserData("Account verification only, no need for any response.");
 
@@ -31,11 +35,19 @@ QPair<int, QString> UniversalAPI::verify()
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
+    if (errorpair.first != 0) {
+        qCWarning(logLLM) << "UniversalAPI Account verification failed with error:" << errorpair.first << errorpair.second;
+    } else {
+        qCDebug(logLLM) << "UniversalAPI Account verification successful";
+    }
+
     return errorpair;
 }
 
 QJsonObject UniversalAPI::predict(const QString &content, const QJsonArray &functions)
 {
+    qCInfo(logLLM) << "UniversalAPI Starting prediction with content length:" << content.length() 
+                   << "and" << functions.size() << "functions";
     AIConversation conversion;
     conversion.addUserData(content);
     conversion.setFunctions(functions);
@@ -44,8 +56,10 @@ QJsonObject UniversalAPI::predict(const QString &content, const QJsonArray &func
     QString systemRole = m_params.value(PREDICT_PARAM_SYSTEMROLE).toString();
     qreal temperature = m_params.value(PREDICT_PARAM_TEMPERATURE, 1.0).toReal();
 
-    if (!systemRole.isEmpty())
+    if (!systemRole.isEmpty()) {
+        qCDebug(logLLM) << "UniversalAPI Setting system role for prediction";
         conversion.setSystemData(systemRole);
+    }
 
     UniversalChatCompletion chatCompletion(apiUrl(), m_accountProxy.account);
     connect(this, &UniversalAPI::aborted, &chatCompletion, &UniversalChatCompletion::requestAborted);
@@ -60,13 +74,16 @@ QJsonObject UniversalAPI::predict(const QString &content, const QJsonArray &func
 
     QJsonObject tools = conversion.getLastTools();
     if (!tools.isEmpty()) {
+        qCDebug(logLLM) << "UniversalAPI Prediction returned with tools data";
         response["tools"] = tools;
     }
+    
     return response;
 }
 
 QList<QByteArray> UniversalAPI::text2Image(const QString &prompt, int number)
 {
+    qCDebug(logLLM) << "UniversalAPI Starting text-to-image conversion for prompt, size:" << prompt.size();
     UniversalImage textToImage(apiUrl(), m_accountProxy.account);
     connect(this, &UniversalAPI::aborted, &textToImage, &UniversalImage::requestAborted);
 
@@ -75,13 +92,25 @@ QList<QByteArray> UniversalAPI::text2Image(const QString &prompt, int number)
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
+    if (errorpair.first != 0) {
+        qCWarning(logLLM) << "UniversalAPI Text-to-image conversion failed with error:" << errorpair.first << errorpair.second;
+    } else {
+        qCDebug(logLLM) << "UniversalAPI Text-to-image conversion successful, generated" << imageData.size() << "images";
+    }
+
     return imageData;
 }
 
 void UniversalAPI::onReadyReadChatDeltaContent(const QByteArray &content)
 {
-    if (content.isEmpty() || !stream())
+    if (content.isEmpty())
         return;
+
+    m_replied = true;
+
+    if (!stream())
+        return;
+
     const QJsonObject &deltacontent = AIConversation::parseContentString(content);
     readyThinkChainContent(deltacontent);
 }
