@@ -3,9 +3,10 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "universalchatcompletion.h"
+#include <QLoggingCategory>
 
 UOSAI_USE_NAMESPACE
-
+Q_DECLARE_LOGGING_CATEGORY(logLLM)
 UniversalChatCompletion::UniversalChatCompletion(const QString &url, const AccountProxy &account)
     : AINetWork(account)
     , rootUrl(url)
@@ -26,6 +27,10 @@ QPair<int, QString> UniversalChatCompletion::create(const QString &model, AIConv
     dataObject.insert("temperature", qBound(0.01, temperature, 0.99)); // zhihu模型的取值为(0, 1)的开区间
     dataObject.insert("stream", true);
 
+    qCDebug(logLLM) << "Universal Creating chat completion for model:" << model 
+                   << "with" << conversation.getConversions().size() << "messages"
+                   << rootUrlPath();
+
     if (!conversation.getFunctions().isEmpty()) {
         QJsonArray tools;
         for (const QJsonValue &func : conversation.getFunctions()) {
@@ -35,13 +40,17 @@ QPair<int, QString> UniversalChatCompletion::create(const QString &model, AIConv
             tools.append(funcObj);
         }
         dataObject.insert("tools", tools);
+        qCInfo(logLLM) << "Universal Added" << tools.size() << "tools/functions to request";
     }
 
     const QString suffix = "/chat/completions";
     const QPair<int, QByteArray> &resultPairs = request(dataObject, rootUrlPath().contains(suffix) ? "" : suffix);
 
-    if (resultPairs.first != 0)
+    if (resultPairs.first != 0) {
+        qCWarning(logLLM) << "Universal Chat completion request failed with error:" << resultPairs.first
+                         << "Message:" << resultPairs.second;
         return qMakePair(resultPairs.first, resultPairs.second);
+    }
 
     conversation.update(resultPairs.second);
     return qMakePair(0, QString());
