@@ -5,6 +5,9 @@
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QJsonArray>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logLLM)
 
 ZhiPuAI::ZhiPuAI(const LLMServerProxy &serverproxy)
     : LLM(serverproxy)
@@ -14,6 +17,9 @@ ZhiPuAI::ZhiPuAI(const LLMServerProxy &serverproxy)
 
 QJsonObject ZhiPuAI::predict(const QString &content, const QJsonArray &functions)
 {
+    qCDebug(logLLM) << "ZhiPuAI Starting prediction with content length:" << content.length() 
+                   << "and" << functions.size() << "functions";
+
     ZhiPuConversation conversion;
     conversion.addUserData(content);
     conversion.setFunctions(functions);
@@ -34,12 +40,15 @@ QJsonObject ZhiPuAI::predict(const QString &content, const QJsonArray &functions
     QJsonObject tools = conversion.getLastTools();
     if (!tools.isEmpty()) {
         response["tools"] = tools;
+        qCDebug(logLLM) << "ZhiPuAI Tools data included in response";
     }
     return response;
 }
 
 QPair<int, QString> ZhiPuAI::verify()
 {
+    qCDebug(logLLM) << "ZhiPuAI Starting account verification";
+
     ZhiPuConversation conversion;
     conversion.addUserData("Account verification only, no need for any response.");
 
@@ -50,12 +59,24 @@ QPair<int, QString> ZhiPuAI::verify()
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
+    if (errorpair.first != 0) {
+        qCWarning(logLLM) << "ZhiPuAI Account verification failed with error:" << errorpair.first 
+                         << "-" << errorpair.second;
+    } else {
+        qCDebug(logLLM) << "ZhiPuAI Account verification successful";
+    }
+
     return errorpair;
 }
 
 void ZhiPuAI::onReadyReadChatDeltaContent(const QByteArray &content)
 {
-    if (content.isEmpty() || !stream())
+    if (content.isEmpty())
+        return;
+
+    m_replied = true;
+
+    if (!stream())
         return;
 
     const QPair<int, QString> &deltacontent = ZhiPuConversation::parseContentString(content);
