@@ -15,21 +15,27 @@
 #include <DLog>
 #include <DGuiApplicationHelper>
 
+// Add logging category declaration
+Q_DECLARE_LOGGING_CATEGORY(logMain)
+
 UOSAI_USE_NAMESPACE
 
 int main(int argc, char *argv[])
 {
+    qCInfo(logMain) << "Starting UOS AI application";
     UosInfo();
 
 #ifdef QT_DEBUG
     qputenv("QTWEBENGINE_REMOTE_DEBUGGING", "10777");
+    qCDebug(logMain) << "Enabled remote debugging for WebEngine";
 #endif
     qputenv("QTWEBENGINE_CHROMIUM_FLAGS", "--enable-logging --log-level=2 --no-sandbox");
 
     Application a(argc, argv);
 
     if (!QDBusConnection::sessionBus().isConnected()) {
-        qCritical() << "Cannot connect to the D-Bus session bus." << QDBusConnection::sessionBus().lastError().message();
+        qCCritical(logMain) << "Cannot connect to the D-Bus session bus:"
+                          << QDBusConnection::sessionBus().lastError().message();
         return -1;
     }
 
@@ -37,17 +43,19 @@ int main(int argc, char *argv[])
         QDBusConnection connection = QDBusConnection::sessionBus();
         bool isServiceRegistered = connection.interface()->isServiceRegistered(DBUS_SERVER);
         if (!isServiceRegistered) {
-            qCritical() << "Cannot launch the WordWizard without starting UOS AI" ;
+            qCCritical(logMain) << "Cannot launch the WordWizard without starting UOS AI";
             return -1;
         }
     }
 
-    //if it already exists then just exit
     if (!ServerWrapper::registerService()) {
+        qCInfo(logMain) << "Service already registered, handling existing arguments";
         return Application::handleExistingArgument(argc, argv);
     }
+
 #ifndef COMPILE_ON_V25
     if (ESystemContext::isWayland()) {
+        qCInfo(logMain) << "Running on Wayland, configuring environment";
         qputenv("QT_WAYLAND_SHELL_INTEGRATION", "kwayland-shell");
 
         QProcess process;
@@ -56,6 +64,7 @@ int main(int argc, char *argv[])
         QString outputString = QString::fromLocal8Bit(process.readAllStandardOutput());
         //以下机型释放webengien时会在mali驱动中闪退，华为海思修复改问题会带来系统整体性能问题，所以我们通过不使用客户端缓存来针对性解决闪退问题
         if (outputString.contains("PWC30")) {
+            qCWarning(logMain) << "Detected special hardware, disabling client buffer integration";
             qputenv("QT_WAYLAND_CLIENT_BUFFER_INTEGRATION", "null");
         }
 
@@ -65,6 +74,7 @@ int main(int argc, char *argv[])
 
     Dtk::Core::DLogManager::registerConsoleAppender();
     Dtk::Core::DLogManager::registerFileAppender();
+    qCInfo(logMain) << "Registered log appenders";
 
     // 初始化文件监视器
     GFWatcher();
@@ -86,10 +96,13 @@ int main(int argc, char *argv[])
     // 提前初始化
     WelcomeDialog::instance();
 
+    QObject::connect(WelcomeDialog::instance(), &WelcomeDialog::signalShowMgmtWindowAfterChatInitFinished, &a, &Application::onSignalShowMgmtWindowAfterChatInitFinished);
+
     UOSAI_NAMESPACE::WordWizard *wizard = new UOSAI_NAMESPACE::WordWizard;//未释放
 
     a.initWordWizard(wizard);
     a.initialization();
 
+    qCInfo(logMain) << "UOS AI initialization completed, entering main event loop";
     return a.exec();
 }
