@@ -4,9 +4,11 @@
 
 #include <QLocalServer>
 #include <QLocalSocket>
-
 #include <QJsonDocument>
 #include <QJsonObject>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logHttp)
 
 AppSocketServer::AppSocketServer(const QString &id, bool noJson, QObject *parent)
     : QObject(parent)
@@ -32,15 +34,16 @@ bool AppSocketServer::startServer()
 
     // 删除旧的套接字文件
     if (!QLocalServer::removeServer(m_serverName)) {
-        qWarning() << "Failed to remove server:" << m_localServer->errorString();
+        qCWarning(logHttp) << "Failed to remove server:" << m_localServer->errorString();
     }
 
     // 开始监听
     if (!m_localServer->listen(m_serverName)) {
-        qWarning() << "Failed to start server:" << m_localServer->errorString();
+        qCCritical(logHttp) << "Failed to start server:" << m_localServer->errorString();
         return false;
     }
 
+    qCDebug(logHttp) << "Server started successfully on" << m_serverName;
     return true;
 }
 
@@ -55,6 +58,7 @@ void AppSocketServer::handleNewConnection()
     connect(clientSocket, &QLocalSocket::disconnected, clientSocket, &QLocalSocket::deleteLater);
     connect(clientSocket, &QLocalSocket::readyRead, this, &AppSocketServer::handleReadyRead);
     connect(clientSocket, &QLocalSocket::bytesWritten, this, &AppSocketServer::handleBytesWritten);
+    qCDebug(logHttp) << m_serverName << "New client connected";
 }
 
 void AppSocketServer::handleReadyRead()
@@ -62,8 +66,6 @@ void AppSocketServer::handleReadyRead()
     QLocalSocket *clientSocket = qobject_cast<QLocalSocket *>(sender());
     if (!clientSocket)
         return;
-
-    qDebug() << clientSocket->readAll();
 }
 
 void AppSocketServer::handleBytesWritten(qint64 bytes)
@@ -74,8 +76,10 @@ void AppSocketServer::handleBytesWritten(qint64 bytes)
 void AppSocketServer::sendDataToClient(const QString &data)
 {
     QList<QLocalSocket *> connectedSockets = m_localServer->findChildren<QLocalSocket *>();
-    if (connectedSockets.isEmpty())
-        qWarning() << "no client to recv stream data." << m_serverName;
+    if (connectedSockets.isEmpty()) {
+        qCWarning(logHttp) << "No clients connected to receive stream data on server:" << m_serverName;
+        return;
+    }
 
     QString pureContent;
     if (m_noJson) {
