@@ -8,7 +8,7 @@ class AppSocketServer : public QObject
 {
     Q_OBJECT
 public:
-    explicit AppSocketServer(const QString &id, bool noJoson = false, QObject *parent = nullptr);
+    explicit AppSocketServer(const QString &id, bool noJson = false, QObject *parent = nullptr);
     ~AppSocketServer();
 
 public:
@@ -24,6 +24,10 @@ public:
      */
     qint64 sendWrittenBytes();
 
+    inline bool outputWithJson() const {
+        return !m_noJson;
+    }
+
 public slots:
     /**
      * @brief sendDataToClient
