@@ -9,6 +9,9 @@
 #include <QJsonObject>
 #include <QStandardPaths>
 #include <QFileInfo>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logTAS)
 
 UosSimpleLog::UosSimpleLog(QObject *parent)
     : QThread(parent)
@@ -40,6 +43,7 @@ void UosSimpleLog::addLog(const UosLogObject &logObj)
         m_mutex.lock();
         m_condition.wakeAll();
         m_mutex.unlock();
+        qCDebug(logTAS) << "Log object enqueued, type:" << logObj.type;
     }
 }
 
@@ -50,6 +54,7 @@ void UosSimpleLog::addRateLog(const UosRateLog &logObj)
         m_mutex.lock();
         m_condition.wakeAll();
         m_mutex.unlock();
+        qCDebug(logTAS) << "Rate log enqueued";
     }
 }
 
@@ -86,7 +91,7 @@ void UosSimpleLog::run()
                 int nCount = 3;
                 while (nCount-- > 0) {
                     if (QNetworkReply::NetworkError::NoError != pushLog(logObj)) {
-                        qWarning() << "Try push log again.";
+                        qCWarning(logTAS) << "Try push log again, type:" << logObj.type << ", left retry:" << nCount;
                     } else {
                         break;
                     }
@@ -100,7 +105,7 @@ void UosSimpleLog::run()
                 int nCount = 3;
                 while (nCount-- > 0) {
                     if (QNetworkReply::NetworkError::NoError != pushLog(logObj)) {
-                        qWarning() << "Try push rate log again.";
+                        qCWarning(logTAS) << "Try push rate log again, left retry:" << nCount;
                     } else {
                         break;
                     }
@@ -192,8 +197,7 @@ int UosSimpleLog::sendLog(const QByteArray &sendData, UosLogType logType)
         }
     }
     if (netReplyError != QNetworkReply::NetworkError::NoError) {
-        qWarning() << "push log failed: \n\tReq: " << sendData.toStdString().c_str()
-                   << " \n\tResp: " << loop.getHttpResult().toStdString().c_str();
+        qCWarning(logTAS) << "Push log failed, type:" << logType << ", req size:" << sendData.size() << ", resp:" << loop.getHttpResult();
     }
 
     return netReplyError;
