@@ -14,6 +14,9 @@
 #include <QProcess>
 #include <QDBusInterface>
 
+#include <QLoggingCategory>
+Q_DECLARE_LOGGING_CATEGORY(logTools)
+
 FunctionsParser::FunctionsParser(const QJsonObject &function)
     : QThread(nullptr)
     , m_function(function)
@@ -43,6 +46,7 @@ QString FunctionsParser::directOutput() const
 
 void FunctionsParser::sendMailFunction(const QJsonObject &argumentsObj)
 {
+    qCDebug(logTools) << "Preparing to send email:" << argumentsObj;
     QString subject = argumentsObj.value("subject").toString();
     QString content = argumentsObj.value("content").toString();
     QStringList toList = argumentsObj.value("to").toString().split(",");
@@ -87,6 +91,7 @@ void FunctionsParser::sendMailFunction(const QJsonObject &argumentsObj)
 
 void FunctionsParser::openUrl(const QString &url)
 {
+    qCDebug(logTools) << "Attempting to open URL:" << url;
     QProcess process;
     process.setProgram("xdg-open");
     process.setArguments({url});
@@ -107,11 +112,12 @@ void FunctionsParser::openUrl(const QString &url)
     m_outputString = outputString;
 
     if (exitCode != 0)
-        qWarning() << url << "Exit code: " << exitCode << "Standard Output: " << outputString;
+        qCWarning(logTools) << "Failed to open URL:" << url << "Exit code:" << exitCode << "Standard Output:" << outputString;
 }
 
 void FunctionsParser::openExec(const QString &mimeType)
 {
+    qCDebug(logTools) << "Looking up default application for MIME type:" << mimeType;
     QProcess process;
     QString command = QString("xdg-mime query default %1").arg(mimeType);
     process.start(command);
@@ -124,15 +130,19 @@ void FunctionsParser::openExec(const QString &mimeType)
         outputString = outLst.last();
 
     m_outputString = outputString;
-    qWarning() << "Exit code: " << m_exitCode << "Standard Output: " << outputString;
-
-    if (m_exitCode != 0)
+    
+    if (m_exitCode != 0) {
+        qCWarning(logTools) << "Failed to query default application for MIME type:" << mimeType
+                           << "Exit code:" << m_exitCode
+                           << "Error output:" << outputString;
         return;
+    }
+    qCInfo(logTools) << "Exit code:" << m_exitCode << "Standard Output:" << outputString;
 
     outputString = outputString.trimmed();
     if (!outputString.endsWith(".desktop")) {
         m_exitCode = 1;
-        qWarning() << "FunctionsParser::openExec " << outputString;
+        qCWarning(logTools) << "FunctionsParser::openExec " << outputString;
         return;
     }
 
@@ -143,12 +153,13 @@ void FunctionsParser::openExec(const QString &mimeType)
     if (!error.isEmpty()) {
         m_exitCode = 1;
         m_outputString = error;
-        qCritical() << error;
+        qCCritical(logTools) << "Failed to launch application:" << error;
     }
 }
 
 void FunctionsParser::run()
 {
+    qCDebug(logTools) << "Starting function execution";
     m_exitCode = 0;
     m_outputString.clear();
 
@@ -157,7 +168,7 @@ void FunctionsParser::run()
 
     const QString &funName = m_function.value("name").toString();
     const QJsonObject &argumentsObj = QJsonDocument::fromJson(m_function.value("arguments").toString().toUtf8()).object();
-    qInfo() << QString("FunctionCalling-functionName:%1  arguments:%2").arg(funName).arg(m_function.value("arguments").toString());
+    qCInfo(logTools) << QString("FunctionCalling-functionName:%1  arguments:%2").arg(funName).arg(m_function.value("arguments").toString());
     if (funName == "sendMail") {
         sendMailFunction(argumentsObj);
     } else if (funName == "openBluetooth") {
@@ -178,7 +189,7 @@ void FunctionsParser::run()
         else if (modestr == "Efficent")
             mode = 1;
         else
-            qWarning() << "function args error = " << argumentsObj;
+            qCWarning(logTools) << "Function name:" << funName << "function args error:" << argumentsObj;
 
         content = UosAbility()->doDockModeSwitch(mode);
     } else if (funName == "switchSystemTheme") {
@@ -191,7 +202,7 @@ void FunctionsParser::run()
         else if (modestr == "Auto")
             mode = 2;
         else
-            qWarning() << "function args error = " << argumentsObj;
+            qCWarning(logTools) << "Function name:" << funName << "function args error:" << argumentsObj;
 
         content = UosAbility()->doSystemThemeSwitch(mode);
     } else if (funName == "switchEyesProtection") {
@@ -238,7 +249,7 @@ void FunctionsParser::run()
         else if (modestr == "Extend")
             mode = 2;
         else
-            qWarning() << "function args error = " << argumentsObj;
+            qCWarning(logTools) << "Function name:" << funName << "function args error:" << argumentsObj;
 
         content = UosAbility()->doDisplayModeSwitch(mode);
     } else if (funName == "switchScreen") {
@@ -254,11 +265,13 @@ void FunctionsParser::run()
     } else {
         content.error = OSCallContext::NotImpl;
         content.errorInfo = funName + QCoreApplication::translate("FunctionsParser", "Function not available");
-
-        qWarning() << "function name error = " << m_function;
     }
 
     if (content.error != OSCallContext::NonError) {
+        qCWarning(logTools) << "Function execution failed:" << funName 
+                           << "Error code:" << content.error
+                           << "Error info:" << content.errorInfo
+                           << "Function:" << m_function;
         m_exitCode = content.error;
         m_outputString = content.errorInfo;
     }
