@@ -20,6 +20,13 @@
 #include <QMimeDatabase>
 #include <QDesktopServices>
 #include <QCryptographicHash>
+#include <QPixmap>
+#include <QPainter>
+#include <QFileInfo>
+#include <QImageReader>
+
+#include <QLoggingCategory>
+Q_DECLARE_LOGGING_CATEGORY(logUtils)
 
 DCORE_USE_NAMESPACE
 DWIDGET_USE_NAMESPACE
@@ -42,7 +49,7 @@ bool Util::isWayland()
         } else {
             wayland = 0;
         }
-        qInfo() << "is wayland" << wayland;
+        qCInfo(logUtils) << "Check is wayland:" << wayland;
     }
 
     return wayland == 1;
@@ -79,8 +86,8 @@ void Util::playSystemSound_SSE_Error()
 
 bool Util::isGPTEnable()
 {
-    qDebug() << "productType" << DSysInfo::productType()
-             << "language" << QLocale::system().language() << QLocale::system().script();
+    qCDebug(logUtils) << "Check productType:" << DSysInfo::productType()
+             << "language:" << QLocale::system().language() << QLocale::system().script();
     if (isCommunity())
         return true;
 
@@ -141,7 +148,7 @@ QString Util::textEncodingTransferUTF8(const std::string &content)
     if (Dtk::Core::DTextEncoding::convertTextEncoding(data, out, "utf-8", codeFormat.toUtf8())) {
         return QString::fromUtf8(out);
     } else {
-        qWarning() << "Failed to convert encoding from" << codeFormat << "to UTF-8";
+        qCWarning(logUtils) << "Failed to convert encoding from" << codeFormat << "to UTF-8";
         return "";
     }
 }
@@ -170,7 +177,7 @@ bool Util::openFileFromPath(const QString &path)
     if (fileInfo.exists()) {
         openOK = QDesktopServices::openUrl(QUrl::fromLocalFile(path));
     } else {
-        qWarning() << __FUNCTION__
+        qCWarning(logUtils) << __FUNCTION__
                    << " file can't find:" << path;
     }
 
@@ -186,21 +193,21 @@ bool Util::launchUosBrowser(QString url) {
         // 注意：不需要手动释放 GAppInfo 对象，因为它们是由 g_app_info_get_all_for_type 管理的
         GAppInfo *appInfo = G_APP_INFO(l->data);
         const char *APP_PATH = g_app_info_get_executable(appInfo);
-        qInfo() << QString("find browser(%1)").arg(APP_PATH);
+        qCInfo(logUtils) << "Find browser:" << APP_PATH;
         // /usr/bin/browser
         if (QString(APP_PATH).endsWith("/browser")) {
             GList *g_files = nullptr;
             GFile *f = g_file_new_for_uri(url.toStdString().c_str());
             g_files = g_list_append(g_files, f);
             GError *gError = nullptr;
-            qInfo() << QString("browser %1").arg(url);
+            qCInfo(logUtils) << "Browser:" << url;
             gboolean ok = g_app_info_launch(appInfo, g_files, nullptr, &gError);
             if (gError) {
-                qWarning() << "Error when trying to open desktop file with gio: " << gError->message;
+                qCWarning(logUtils) << "Error when trying to open desktop file with gio: " << gError->message;
                 g_error_free(gError);
             }
             if (!ok) {
-                qWarning() << "Failed to open desktop file with gio: g_app_info_launch returns false";
+                qCWarning(logUtils) << "Failed to open desktop file with gio: g_app_info_launch returns false";
             } else {
                 ret = true;
             }
@@ -215,14 +222,14 @@ bool Util::launchUosBrowser(QString url) {
             GFile *f = g_file_new_for_uri(url.toStdString().c_str());
             g_files = g_list_append(g_files, f);
             GError *gError = nullptr;
-            qInfo() << QString("ll-cli %1").arg(QString("run org.deepin.browser -- browser ") + url);
+            qCInfo(logUtils) << QString("ll-cli %1").arg(QString("run org.deepin.browser -- browser ") + url);
             gboolean ok = g_app_info_launch(appInfo, g_files, nullptr, &gError);
             if (gError) {
-                qWarning() << "Error when trying to open desktop file with gio: " << gError->message;
+                qCWarning(logUtils) << "Error when trying to open desktop file with gio: " << gError->message;
                 g_error_free(gError);
             }
             if (!ok) {
-                qWarning() << "Failed to open desktop file with gio: g_app_info_launch returns false";
+                qCWarning(logUtils) << "Failed to open desktop file with gio: g_app_info_launch returns false";
             } else {
                 ret = true;
             }
@@ -248,14 +255,14 @@ bool Util::launchDefaultBrowser(QString url) {
     GFile *f = g_file_new_for_uri(url.toStdString().c_str());
     g_files = g_list_append(g_files, f);
     GError *gError = nullptr;
-    qInfo() << QString("browser %1").arg(url);
+    qCInfo(logUtils) << "Browser:" << url;
     gboolean ok = g_app_info_launch(defaultApp, g_files, nullptr, &gError);
     if (gError) {
-        qWarning() << "Error when trying to open desktop file with gio: " << gError->message;
+        qCWarning(logUtils) << "Error when trying to open desktop file with gio: " << gError->message;
         g_error_free(gError);
     }
     if (!ok) {
-        qWarning() << "Failed to open desktop file with gio: g_app_info_launch returns false";
+        qCWarning(logUtils) << "Failed to open desktop file with gio: g_app_info_launch returns false";
     } else {
         ret = true;
     }
@@ -282,3 +289,57 @@ QString Util::imageData2TmpFile(const QString &tmpDir, const QString &imageData)
 
     return imageFileName;
 }
+
+QPixmap Util::loadSvgPixmap(const QString &filePath, const QSize &size)
+{
+    QFileInfo fileInfo(filePath);
+    if (!fileInfo.exists() || !fileInfo.isFile()) {
+        qCWarning(logUtils) << "SVG file does not exist:" << filePath;
+        return QPixmap();
+    }
+
+    auto ratio = qApp->devicePixelRatio();
+
+    QPixmap originalPixmap(filePath);
+    if (originalPixmap.isNull()) {
+        qCWarning(logUtils) << "Failed to load SVG file:" << filePath;
+        return QPixmap();
+    }
+
+    // 检查 QImageReader 是否支持 SVG 格式
+    QList<QByteArray> supportedFormats = QImageReader::supportedImageFormats();
+    bool supportsSvg = supportedFormats.contains("svg") || supportedFormats.contains("SVG");
+
+    if (supportsSvg) {
+        QImageReader reader(filePath);
+        reader.setFormat("svg");
+        reader.setScaledSize(size * ratio);
+        reader.setQuality(100);
+        QImage image = reader.read();
+        if (!image.isNull()) {
+            if (image.size() != size * ratio) {
+                image = image.scaled(size * ratio, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+            }
+            QPixmap pixmap = QPixmap::fromImage(image);
+            pixmap.setDevicePixelRatio(ratio);
+            return pixmap;
+        } else {
+            qCWarning(logUtils) << "Failed to read SVG image with QImageReader:" << filePath << "Error:" << reader.errorString();
+        }
+    }
+
+
+    QPixmap pmap(size * ratio);
+    pmap.fill(Qt::transparent);
+
+    {
+        QPainter painter(&pmap);
+        painter.setRenderHint(QPainter::Antialiasing, true);
+        painter.setRenderHint(QPainter::SmoothPixmapTransform, true);
+        painter.drawPixmap(QRect(QPoint(0, 0), size * ratio), originalPixmap);
+    }
+
+    pmap.setDevicePixelRatio(ratio);
+    return pmap;
+}
+
