@@ -85,7 +85,8 @@ enum ChatAction {
     ChatTextPlain     = 0,      // 纯文本聊天
     ChatFunctionCall  = 1,      // FunctionCall
     ChatText2Image    = 2,       // 文生图
-    ChatTextThink     = 3       // 思考内容
+    ChatTextThink     = 3,       // 思考内容
+    ChatToolUse       = 4        // 智能体工具调用
 };
 
 enum AssistantType {
@@ -93,6 +94,9 @@ enum AssistantType {
     UOS_SYSTEM_ASSISTANT = 0x0002,
     DEEPIN_SYSTEM_ASSISTANT = 0x0003,
     PERSONAL_KNOWLEDGE_ASSISTANT = 0x0004,
+    AI_WRITING = 0x0005,
+    AI_TEXT_PROCESSING = 0x0006,
+    AI_TRANSLATION = 0x0007,
 
     PLUGIN_ASSISTANT = 0x0100
 };
@@ -476,6 +480,15 @@ struct AssistantProxy {
         case PERSONAL_KNOWLEDGE_ASSISTANT:
             name = "Personal Knowledge Assistant";
             break;
+        case AI_WRITING:
+            name = "AI Writing";
+            break;
+        case AI_TEXT_PROCESSING:
+            name = "AI Text Processing";
+            break;
+        case AI_TRANSLATION:
+            name = "AI Translation";
+            break;
         default:
             break;
         }
@@ -498,6 +511,15 @@ struct AssistantProxy {
         case PERSONAL_KNOWLEDGE_ASSISTANT:
             name = QObject::tr("Personal Knowledge Assistant");
             break;
+        case AI_WRITING:
+            name = QObject::tr("AI Writing");
+            break;
+        case AI_TEXT_PROCESSING:
+            name = QObject::tr("AI Text Processing");
+            break;
+        case AI_TRANSLATION:
+            name = QObject::tr("AI Translation");
+            break;
         default:
             break;
         }
@@ -509,16 +531,25 @@ struct AssistantProxy {
 
         switch (type) {
         case UOS_AI:
-            desc = QObject::tr("Welcome to UOS AI, the comprehensive assistant of UOS AI system.");
+            desc = QObject::tr("System's Comprehensive AI Assistant.");
             break;
         case UOS_SYSTEM_ASSISTANT:
-            desc = QObject::tr("UOS System Assistant, answers questions related to using the UOS operating system.");
+            desc = QObject::tr("Assists you with UOS system-related inquiries.");
             break;
         case DEEPIN_SYSTEM_ASSISTANT:
-            desc = QObject::tr("Deepin System Assistant, answering questions related to using the Deepin operating system.");
+            desc = QObject::tr("Assists you with Deepin system-related inquiries.");
             break;
         case PERSONAL_KNOWLEDGE_ASSISTANT:
-            desc = QObject::tr("A personal knowledge assistant who can answer questions and generate content based on your personal file data. You can add or delete knowledge on the Settings - Knowledge Base Management page.");
+            desc = QObject::tr("Answers questions based on your personal knowledge base.");
+            break;
+        case AI_WRITING:
+            desc = QObject::tr("Write Based on Your Topic and Requirements.");
+            break;
+        case AI_TEXT_PROCESSING:
+            desc = QObject::tr("Capable of Handling Text Processing Tasks Such as Summarizing, Proofreading, and Rewriting.");
+            break;
+        case AI_TRANSLATION:
+            desc = QObject::tr("Your Translation Assistant, Mastering Multiple Languages.");
             break;
         default:
             break;
@@ -542,6 +573,15 @@ struct AssistantProxy {
         case PERSONAL_KNOWLEDGE_ASSISTANT:
             iconName = "personal-assistant";
             break;
+        case AI_WRITING:
+            iconName = "ai-writing";
+            break;
+        case AI_TEXT_PROCESSING:
+            iconName = "ai-text-processing";
+            break;
+        case AI_TRANSLATION:
+            iconName = "ai-translation";
+            break;
         default:
             break;
         }
@@ -549,4 +589,26 @@ struct AssistantProxy {
     }
 };
 
+struct ToolUse
+{
+    enum Staus { Calling = 0, Completed, Failed, Canceled };
+    QString name;
+    QString params;
+    QString result;
+    QString content;
+    Staus status = Calling;
+    int index;
+
+   inline QJsonObject toJson() const {
+        QJsonObject obj;
+        obj.insert("name", name);
+        obj.insert("params", params);
+        obj.insert("result", result);
+        obj.insert("content", content);
+        obj.insert("status", static_cast<int>(status));
+        obj.insert("index", index);
+        return  obj;
+    }
+};
+
 #endif // SERVERDEFS_H
