@@ -4,6 +4,10 @@
 #include "serverwrapper.h"
 #include "utils/util.h"
 
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logWrapper)
+
 UOSAI_USE_NAMESPACE
 
 Session::Session(const QString &appId, QObject *parent)
@@ -30,7 +34,8 @@ void Session::updateLLMAccount()
         if (!supLLM.isEmpty()) {
             llm = supLLM.first();
         } else {
-            qWarning() << "no llm for" << m_private->m_assistantProxy.id << m_private->m_assistantProxy.displayName;
+            qCWarning(logWrapper) << "No LLM found for assistant:" << m_private->m_assistantProxy.id 
+                                << "name:" << m_private->m_assistantProxy.displayName;
         }
     }
 
@@ -55,14 +60,16 @@ QPair<AIServer::ErrorType, QStringList> Session::requestChatText(const QString &
 {
     // 兜底检查，如果有办法不同意协议走到这里，直接abort
     if (!DbWrapper::localDbWrapper().getAICopilotIsOpen()) {
-        qCritical() << "the agreement is unagreed. abort";
+        qCCritical(logWrapper) << "AI Copilot agreement not accepted, aborting request";
         abort();
         return {AIServer::AuthenticationRequiredError, QStringList()};
     }
 
     LLMServerProxy tmpLLMAccount = m_private->queryValidServerAccount(llmId);
-    if (tmpLLMAccount.model == PLUGIN_MODEL)
+    if (tmpLLMAccount.model == PLUGIN_MODEL) {
+        qCDebug(logWrapper) << "Using plugin model for request";
         return m_private->requestPlugin(tmpLLMAccount, conversation, params);
+    }
 
     return m_private->requestChatFunctionText(tmpLLMAccount, conversation, params);
 }
@@ -71,7 +78,7 @@ QPair<AIServer::ErrorType, QStringList> Session::requestFunction(const QString &
 {
     // 兜底检查，如果有办法不同意协议走到这里，直接abort
     if (!DbWrapper::localDbWrapper().getAICopilotIsOpen()) {
-        qCritical() << "the agreement is unagreed. abort";
+        qCCritical(logWrapper) << "AI Copilot agreement not accepted, aborting request";
         abort();
         return {AIServer::AuthenticationRequiredError, QStringList()};
     }
@@ -83,11 +90,47 @@ QPair<AIServer::ErrorType, QStringList> Session::requestFunction(const QString &
     return m_private->requestInstFunction(tmpLLMAccount, conversation, funcs, params);
 }
 
+QPair<AIServer::ErrorType, QStringList> Session::requestMcpAgent(const QString &llmId, const QString &conversation, const QVariantHash &params)
+{
+    // 兜底检查，如果有办法不同意协议走到这里，直接abort
+    if (!DbWrapper::localDbWrapper().getAICopilotIsOpen()) {
+        qCCritical(logWrapper) << "AI Copilot agreement not accepted, aborting request";
+        abort();
+        return {AIServer::AuthenticationRequiredError, QStringList()};
+    }
+
+    LLMServerProxy tmpLLMAccount = m_private->queryValidServerAccount(llmId);
+    if (tmpLLMAccount.model == PLUGIN_MODEL) {
+        qCCritical(logWrapper) << "Agent don't support plugin model";
+        return {AIServer::ContentAccessDenied, QStringList()};
+    }
+
+    return m_private->requestAgent(tmpLLMAccount, conversation, params);
+}
+
+QPair<AIServer::ErrorType, QStringList> Session::requestRag(const QString &llmId, const QString &conversation, const QVariantHash &params)
+{
+    // 兜底检查，如果有办法不同意协议走到这里，直接abort
+    if (!DbWrapper::localDbWrapper().getAICopilotIsOpen()) {
+        qCCritical(logWrapper) << "AI Copilot agreement not accepted, aborting request";
+        abort();
+        return {AIServer::AuthenticationRequiredError, QStringList()};
+    }
+
+    LLMServerProxy tmpLLMAccount = m_private->queryValidServerAccount(llmId);
+    if (tmpLLMAccount.model == PLUGIN_MODEL) {
+        qCCritical(logWrapper) << "RAG don't support plugin model";
+        return {AIServer::ContentAccessDenied, QStringList()};
+    }
+
+    return m_private->requestRag(tmpLLMAccount, conversation, params);
+}
+
 QString Session::chatRequest(const QString &llmId, const QString &ctx, const QVariantHash &params)
 {
     // 兜底检查，如果有办法不同意协议走到这里，直接abort
     if (!DbWrapper::localDbWrapper().getAICopilotIsOpen()) {
-        qCritical() << "the agreement is unagreed. abort";
+        qCCritical(logWrapper) << "AI Copilot agreement not accepted, aborting request";
         abort();
         return "";
     }
@@ -100,7 +143,7 @@ QString Session::searchRequest(const QString &llmId, const QString &ctx)
 {
     // 兜底检查，如果有办法不同意协议走到这里，直接abort
     if (!DbWrapper::localDbWrapper().getAICopilotIsOpen()) {
-        qCritical() << "the agreement is unagreed. abort";
+        qCCritical(logWrapper) << "AI Copilot agreement not accepted, aborting request";
         abort();
         return "";
     }
@@ -113,7 +156,7 @@ QString Session::requestGenImage(const QString &llmId, const QString &imageDesc)
 {
     // 兜底检查，如果有办法不同意协议走到这里，直接abort
     if (!DbWrapper::localDbWrapper().getAICopilotIsOpen()) {
-        qCritical() << "the agreement is unagreed. abort";
+        qCCritical(logWrapper) << "AI Copilot agreement not accepted, aborting request";
         abort();
         return "";
     }
@@ -124,8 +167,12 @@ QString Session::requestGenImage(const QString &llmId, const QString &imageDesc)
 
 bool Session::setCurrentLLMAccountId(const QString &id)
 {
-    if (id.isEmpty())
+    qCDebug(logWrapper) << "Setting current LLM account ID:" << id;
+    
+    if (id.isEmpty()) {
+        qCWarning(logWrapper) << "Empty LLM account ID provided";
         return false;
+    }
 
     {
         QList<LLMServerProxy> llms = m_private->m_llmVendor.queryServerAccountByRole(m_private->m_assistantProxy);
@@ -139,14 +186,18 @@ bool Session::setCurrentLLMAccountId(const QString &id)
         }
 
         if (!found) {
-            qWarning() << "llm" << id << "is not support for " << m_private->m_assistantProxy.id << m_private->m_assistantProxy.displayName;
+            qCWarning(logWrapper) << "LLM" << id << "not supported for assistant:" 
+                                << m_private->m_assistantProxy.id 
+                                << "name:" << m_private->m_assistantProxy.displayName;
             return false;
         }
     }
 
     LLMServerProxy account = m_private->m_llmVendor.setCurrentLLMAccountId(id, m_private->m_appId);
-    if (!account.isValid())
+    if (!account.isValid()) {
+        qCWarning(logWrapper) << "Invalid LLM account:" << id;
         return false;
+    }
 
     if (m_private->m_assistantProxy.type == AssistantType::UOS_AI) {
         m_uosaiTopAccountId = account.id;
@@ -159,9 +210,14 @@ bool Session::setCurrentLLMAccountId(const QString &id)
     return true;
 }
 
-bool Session::setUosAiLLMAccountId(const QString &id) {
-    if (id.isEmpty())
+bool Session::setUosAiLLMAccountId(const QString &id)
+{
+    qCDebug(logWrapper) << "Setting UOS AI LLM account ID:" << id;
+    
+    if (id.isEmpty()) {
+        qCWarning(logWrapper) << "Empty UOS AI LLM account ID provided";
         return false;
+    }
 
     // 固定角色
     QList<AssistantProxy> assistantLst = DbWrapper::localDbWrapper().queryAssistantList();
@@ -179,14 +235,17 @@ bool Session::setUosAiLLMAccountId(const QString &id) {
                 }
 
                 if (!found) {
-                    qWarning() << "llm" << id << "is not support for " << assis.id << assis.displayName;
+                    qCWarning(logWrapper) << "LLM" << id << "not supported for UOS AI assistant:" 
+                                        << assis.id << "name:" << assis.displayName;
                     return false;
                 }
             }
 
             LLMServerProxy account = m_private->m_llmVendor.setCurrentLLMAccountId(id, assis.id);
-            if (!account.isValid())
+            if (!account.isValid()) {
+                qCWarning(logWrapper) << "Invalid UOS AI LLM account:" << id;
                 return false;
+            }
 
             //update role-model table
             DbWrapper::localDbWrapper().updateAssistantLlm(assis.id, account.id);
@@ -199,6 +258,7 @@ bool Session::setUosAiLLMAccountId(const QString &id) {
         }
     }
 
+    qCWarning(logWrapper) << "No UOS AI assistant found";
     return false;
 }
 
@@ -235,28 +295,39 @@ ModelType Session::currentModelType()
 
 bool Session::setCurrentAssistantId(const QString &id)
 {
+    qCDebug(logWrapper) << "Setting current assistant ID:" << id;
+    
     AssistantProxy assistant = DbWrapper::localDbWrapper().queryAssistantByid(id);
     if (!assistant.isValid()) {
+        qCDebug(logWrapper) << "Assistant not found in local DB, querying from vendor";
         assistant = m_private->m_llmVendor.queryAssistantById(id);
-        if (!assistant.isValid())
+        if (!assistant.isValid()) {
+            qCWarning(logWrapper) << "Invalid assistant ID:" << id;
             return false;
+        }
     }
 
     m_private->m_assistantProxy = assistant;
+    qCDebug(logWrapper) << "Updating app's current assistant ID";
     DbWrapper::localDbWrapper().updateAppCurAssistantId(m_private->m_appId, id);
 
     QString llmId = DbWrapper::localDbWrapper().queryLlmIdByAssistantId(m_private->m_assistantProxy.id);
 
     //兼容 uos ai助手尝试去appid配置的模型
-    if (llmId.isEmpty() && m_private->m_assistantProxy.type == UOS_AI)
+    if (llmId.isEmpty() && m_private->m_assistantProxy.type == UOS_AI) {
+        qCDebug(logWrapper) << "No LLM found for assistant, trying app's configured model";
         llmId = DbWrapper::localDbWrapper().queryCurLlmIdByAppId(appId());
+    }
 
     if (!setCurrentLLMAccountId(llmId)) {
+        qCDebug(logWrapper) << "Failed to set LLM account, trying first available LLM";
         auto supLLM = m_private->m_llmVendor.queryServerAccountByRole(m_private->m_assistantProxy);
         if (!supLLM.isEmpty()) {
             setCurrentLLMAccountId(supLLM.first().id);
         } else {
-            qWarning() << "no llm for" << m_private->m_assistantProxy.id << m_private->m_assistantProxy.displayName;
+            qCWarning(logWrapper) << "No LLM available for assistant:" 
+                                << m_private->m_assistantProxy.id 
+                                << "name:" << m_private->m_assistantProxy.displayName;
             m_private->m_appServerProxy = LLMServerProxy();
         }
     }
@@ -280,6 +351,12 @@ QString Session::currentAssistantDisplayName(){
         return tr("Deepin System Assistant");
     case PERSONAL_KNOWLEDGE_ASSISTANT:
         return tr("Personal Knowledge Assistant");
+    case AI_WRITING:
+        return tr("AI Writing");
+    case AI_TEXT_PROCESSING:
+        return tr("AI Text Processing");
+    case AI_TRANSLATION:
+        return tr("AI Translation");
     default:
         return m_private->m_assistantProxy.displayName;
     }
@@ -295,6 +372,12 @@ QString Session::currentAssistantDisplayNameEn(){
         return "Deepin System Assistant";
     case PERSONAL_KNOWLEDGE_ASSISTANT:
         return "Personal Knowledge Assistant";
+    case AI_WRITING:
+        return "AI Writing";
+    case AI_TEXT_PROCESSING:
+        return "AI Text Processing";
+    case AI_TRANSLATION:
+        return "AI Translation";
     default:
         return "3rdparty";
     }
@@ -312,11 +395,14 @@ QString Session::currentAssistantInstList()
 
 QString Session::queryLLMAccountList(const QList<LLMChatModel> &excludes)
 {
+    qCDebug(logWrapper) << "Querying LLM account list with" << excludes.size() << "excluded models";
     return m_private->m_llmVendor.queryLLMAccountList(excludes);
 }
 
 QString Session::queryLLMAccountListWithRole(const QList<LLMChatModel> &excludes)
 {
+    qCDebug(logWrapper) << "Querying LLM account list for role:" << m_private->m_assistantProxy.id 
+                       << "with" << excludes.size() << "excluded models";
     return m_private->m_llmVendor.queryLLMAccountListByRole(m_private->m_assistantProxy, excludes);
 }
 
@@ -389,21 +475,27 @@ AssistantType Session::queryAssistantTypeById(const QString &id)
 
 QString Session::queryIconById(const QString &assistantId, const QString &modelId)
 {
+    qCDebug(logWrapper) << "Querying icon for assistant:" << assistantId << "model:" << modelId;
     return m_private->m_llmVendor.queryIconById(assistantId, modelId);
 }
 
 QString Session::queryDisplayNameById(const QString &assistantId)
 {
+    qCDebug(logWrapper) << "Querying display name for assistant:" << assistantId;
     return m_private->m_llmVendor.queryDisplayNameById(assistantId);
 }
 
 void Session::launchLLMUiPage(bool showAddllmPage, bool onlyUseAgreement, bool isFromAiQuick, const QString &locateTitle)
 {
+    qCDebug(logWrapper) << "Launching LLM UI page - showAddllmPage:" << showAddllmPage 
+                       << "onlyUseAgreement:" << onlyUseAgreement 
+                       << "isFromAiQuick:" << isFromAiQuick;
     emit ServerWrapper::instance()->sigToLaunchMgmt(showAddllmPage, onlyUseAgreement, isFromAiQuick, locateTitle);
 }
 
-void Session::launchKnowledgeBaseUiPage(const QString & locateTitle)
+void Session::launchKnowledgeBaseUiPage(const QString &locateTitle)
 {
+    qCDebug(logWrapper) << "Launching knowledge base UI page";
     emit ServerWrapper::instance()->sigToLaunchMgmt(false, false, false, locateTitle);
 }
 
