@@ -33,7 +33,8 @@ private:
     QPair<AIServer::ErrorType, QStringList> requestChatFunctionText(LLMServerProxy tmpLLMAccount, const QString &conversation, const QVariantHash &params);
     QPair<AIServer::ErrorType, QStringList> requestInstFunction(LLMServerProxy tmpLLMAccount, const QString &conversation, const QJsonArray &funcs, const QVariantHash &params);
     QPair<AIServer::ErrorType, QStringList> requestPlugin(LLMServerProxy tmpLLMAccount, const QString &conversation, const QVariantHash &params);
-
+    QPair<AIServer::ErrorType, QStringList> requestAgent(LLMServerProxy tmpLLMAccount, const QString &conversation, const QVariantHash &params);
+    QPair<AIServer::ErrorType, QStringList> requestRag(LLMServerProxy tmpLLMAccount, const QString &conversation, const QVariantHash &params);
     // 只返回reqID，error统一通过信号发送
     QString chatRequest(LLMServerProxy llmAccount, const QString &ctx, const QVariantHash &params);
     QString genImageRequest(LLMServerProxy tmpLLMAccount, const QString &imageDesc);
@@ -90,6 +91,10 @@ private:
 
     QVariant getFAQ();
 
+    void increaseAccountUsage(const LLMServerProxy &llmAccount, int chatAction) const;
+
+    QString ragPromptBuild(const QString &conversation);
+
 private slots:
     /**
      * @brief Task request has ended.
