@@ -1,4 +1,7 @@
 #include "treelandddeactivev1.h"
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logTreeland)
 
 TreelandDDEShellManageV1::TreelandDDEShellManageV1()
     : QWaylandClientExtensionTemplate<TreelandDDEShellManageV1>(TREELANDDDESHELLMANAGERV1VERSION)
@@ -23,13 +26,13 @@ TreelandDDEActiveV1::~TreelandDDEActiveV1()
 
 void TreelandDDEActiveV1::treeland_dde_active_v1_active_in(uint32_t reason)
 {
-//    qWarning() << "recvie button activeIn, reson:" << reason;
+    qCDebug(logTreeland) << "Active in event received, reason:" << reason;
     Q_EMIT mousePress();
 }
 
 void TreelandDDEActiveV1::treeland_dde_active_v1_active_out(uint32_t reason)
 {
-//    qWarning() << "recvie button activeOut, reson:" << reason;
+    qCDebug(logTreeland) << "Active out event received, reason:" << reason;
     Q_EMIT mouseRelease();
 }
 
